@@ -152,7 +152,7 @@ TagsManager::~TagsManager()
 	wxCriticalSectionLocker locker(m_cs);
 	if (m_canDeleteCtags) {
 		if (m_codeliteIndexerProcess) m_codeliteIndexerProcess->Disconnect(m_codeliteIndexerProcess->GetUid(), wxEVT_END_PROCESS, wxProcessEventHandler(TagsManager::OnCtagsEnd), NULL, this);
-		
+
 		// terminate ctags process
 		if (m_codeliteIndexerProcess) m_codeliteIndexerProcess->Terminate();
 
@@ -325,13 +325,13 @@ clProcess *TagsManager::StartCtagsProcess()
 	// build the command, we surround ctags name with double quatations
 	wxString uid;
 	uid << wxGetProcessId();
-	
+
 	if(m_codeliteIndexerPath.FileExists() == false) {
 		wxLogMessage(wxT("ERROR: Could not locate indexer: %s"), m_codeliteIndexerPath.GetFullPath().c_str());
 		m_codeliteIndexerProcess = NULL;
 		return NULL;
 	}
-	
+
 	// concatenate the PID to identifies this channel to this instance of codelite
 	cmd << wxT("\"") << m_codeliteIndexerPath.GetFullPath() << wxT("\" ") << uid << wxT(" --pid");
 	clProcess* process;
@@ -477,7 +477,10 @@ void TagsManager::SourceToTags(const wxFileName& source, wxString& tags)
 	}
 
 	// convert the data into wxString
-	tags = wxString::From8BitData(reply.getTags().c_str());
+	tags = wxString(reply.getTags().c_str(), wxConvUTF8);
+	if(tags.empty()) {
+		tags = wxString::From8BitData(reply.getTags().c_str());
+	}
 }
 
 TagTreePtr TagsManager::TreeFromTags(const wxString& tags, int &count)
@@ -614,13 +617,13 @@ bool TagsManager::WordCompletionCandidates(const wxFileName &fileName, int linen
 
 	wxString scope;
 	wxString scopeName = GetLanguage()->GetScopeName(text, &additionlScopes);
-	
+
 	if( GetCtagsOptions().GetFlags() &  CC_DEEP_SCAN_USING_NAMESPACE_RESOLVING ) {
 		// Do a deep scan for 'using namespace'
 		GetLanguage()->SetAdditionalScopes(additionlScopes, fileName.GetFullPath());
 		additionlScopes = GetLanguage()->GetAdditionalScopes();
 	}
-	
+
 	TagEntryPtr funcTag = FunctionFromFileLine(fileName, lineno);
 	if (funcTag) {
 		funcSig = funcTag->GetSignature();
@@ -644,7 +647,8 @@ bool TagsManager::WordCompletionCandidates(const wxFileName &fileName, int linen
 			TagsByScopeAndName(additionlScopes.at(i), word, tmpCandidates);
 		}
 
-		RemoveDuplicates  (tmpCandidates, candidates);
+		DoFilterDuplicatesByTagID  (tmpCandidates, candidates);
+		DoFilterDuplicatesBySignature(candidates, candidates);
 
 	} else if( tmpExp == wxT("::") ) {
 		// Global scope only
@@ -652,7 +656,8 @@ bool TagsManager::WordCompletionCandidates(const wxFileName &fileName, int linen
 		// Collect all tags from the global scope which starts with 'My' (i.e. 'word')
 		std::vector<TagEntryPtr> tmpCandidates;
 		GetGlobalTags     (word, tmpCandidates);
-		RemoveDuplicates  (tmpCandidates, candidates);
+		DoFilterDuplicatesByTagID  (tmpCandidates, candidates);
+		DoFilterDuplicatesBySignature(candidates, candidates);
 
 	} else {
 		wxString typeName, typeScope, dummy;
@@ -669,9 +674,29 @@ bool TagsManager::WordCompletionCandidates(const wxFileName &fileName, int linen
 		else
 			scope << typeScope << wxT("::") << typeName;
 
-		std::vector<TagEntryPtr> tmpCandidates;
+		std::vector<TagEntryPtr> tmpCandidates, tmpCandidates1;
 		TagsByScope(scope, tmpCandidates);
-		RemoveDuplicates(tmpCandidates, candidates);
+
+		wxString partialName(word);
+		partialName.MakeLower();
+
+		if(partialName.IsEmpty() == false)
+		{
+			for(size_t i=0; i<tmpCandidates.size(); i++) {
+				wxString nm = tmpCandidates[i]->GetName();
+				nm.MakeLower();
+				if(nm.StartsWith(partialName)) {
+					tmpCandidates1.push_back( tmpCandidates.at(i) );
+				}
+			}
+			DoFilterDuplicatesByTagID(tmpCandidates1, candidates);
+			DoFilterDuplicatesBySignature(candidates, candidates);
+		}
+		else
+		{
+			DoFilterDuplicatesByTagID(tmpCandidates, candidates);
+			DoFilterDuplicatesBySignature(candidates, candidates);
+		}
 	}
 
 	PERF_END();
@@ -681,7 +706,7 @@ bool TagsManager::WordCompletionCandidates(const wxFileName &fileName, int linen
 bool TagsManager::AutoCompleteCandidates(const wxFileName &fileName, int lineno, const wxString& expr, const wxString& text, std::vector<TagEntryPtr>& candidates)
 {
 	PERF_START("AutoCompleteCandidates");
-	
+
 	candidates.clear();
 	wxString path;
 	wxString typeName, typeScope;
@@ -760,16 +785,65 @@ bool TagsManager::AutoCompleteCandidates(const wxFileName &fileName, int lineno,
 	return candidates.empty() == false;
 }
 
-void TagsManager::RemoveDuplicates(std::vector<TagEntryPtr>& src, std::vector<TagEntryPtr>& target)
+void TagsManager::DoFilterDuplicatesBySignature(std::vector<TagEntryPtr>& src, std::vector<TagEntryPtr>& target)
 {
+	// filter out all entries with the same signature (we do keep declaration overa an implenetation
+	// since usually the declaration contains more useful information)
+	std::map<wxString, TagEntryPtr> others, impls;
+
 	for (size_t i=0; i<src.size(); i++) {
-		if (i == 0) {
-			target.push_back(src.at(0));
-		} else {
-			if (src.at(i)->GetName() != target.at(target.size()-1)->GetName()) {
-				target.push_back(src.at(i));
+		const TagEntryPtr& t = src.at(i);
+		if(t->IsMethod()) {
+			wxString strippedSignature = NormalizeFunctionSig(t->GetSignature(), 0);
+			strippedSignature.Prepend( t->GetName() );
+
+			if(t->IsPrototype()) {
+				// keep declaration in the output map
+				others[strippedSignature] = t;
+			} else {
+				// keep the signature in a different map
+				impls[strippedSignature] = t;
 			}
+		} else {
+			// keep all other entries
+			others[t->GetName()] = t;
 		}
+
+	}
+
+	// unified the two multimaps
+	std::map<wxString, TagEntryPtr>::iterator iter = impls.begin();
+	for(; iter != impls.end(); iter++) {
+		if(others.find(iter->first) == others.end()) {
+			others[iter->first] = iter->second;
+		}
+	}
+
+	target.clear();
+	// convert the map into vector
+	iter = others.begin();
+	for(; iter != others.end(); iter++) {
+		target.push_back(iter->second);
+	}
+}
+
+void TagsManager::DoFilterDuplicatesByTagID(std::vector<TagEntryPtr>& src, std::vector<TagEntryPtr>& target)
+{
+	std::map<int, TagEntryPtr> mapTags;
+
+	for (size_t i=0; i<src.size(); i++) {
+		const TagEntryPtr& t = src.at(i);
+		int tagId = t->GetId();
+		if(mapTags.find(tagId) == mapTags.end()) {
+			mapTags[tagId] = t;
+		} else {
+			tagId = -1;
+		}
+	}
+
+	std::map<int, TagEntryPtr>::iterator iter = mapTags.begin();
+	for(; iter != mapTags.end(); iter++) {
+		target.push_back( iter->second );
 	}
 }
 
@@ -1124,6 +1198,9 @@ void TagsManager::RetagFiles(const std::vector<wxFileName> &files, bool quickRet
 		strFiles.Add(files.at(i).GetFullPath());
 	}
 
+	if(strFiles.IsEmpty())
+		return;
+
 	// step 2: remove all files which do not need retag
 	if ( quickRetag )
 		DoFilterNonNeededFilesForRetaging(strFiles, m_workspaceDatabase);
@@ -1141,14 +1218,27 @@ void TagsManager::RetagFiles(const std::vector<wxFileName> &files, bool quickRet
 
 	// step 5: build the database
 
-	if (DoBuildDatabase(strFiles, *m_workspaceDatabase)) {
+#if USE_PARSER_TREAD_FOR_RETAGGING_WORKSPACE
 
-		// update the last_retagged field in the database for these files
-		UpdateFilesRetagTimestamp(strFiles, m_workspaceDatabase);
+	// Expermintal code: perform the 'retag workspace' using the parser thread
+	// Put a request to the parsing thread
+	ParseRequest *req = new ParseRequest();
+	req->setDbFile( GetDatabase()->GetDatabaseFileName().GetFullPath().c_str() );
+	req->setType  ( ParseRequest::PR_PARSE_AND_STORE );
+
+	req->_workspaceFiles.clear();
+	req->_workspaceFiles.reserve( strFiles.size() );
+	for(size_t i=0; i<strFiles.GetCount(); i++) {
+		req->_workspaceFiles.push_back( strFiles[i].mb_str(wxConvUTF8).data() );
 	}
+	ParseThreadST::Get()->Add ( req );
 
-	// step 7: update the file tree
+#else
+	// step 5: build the database
+	DoBuildDatabase(strFiles, *m_workspaceDatabase);
 	UpdateFileTree(m_workspaceDatabase, true);
+
+#endif
 }
 
 bool TagsManager::DoBuildDatabase(const wxArrayString &files, ITagsStorage &db, const wxString *rootPath)
@@ -1188,6 +1278,10 @@ bool TagsManager::DoBuildDatabase(const wxArrayString &files, ITagsStorage &db,
 		parsing_result.tree = ParseSourceFile(curFile);
 
 		db.Store(parsing_result.tree, wxFileName(), false);
+		if(db.InsertFileEntry(curFile.GetFullPath(), (int)time(NULL)) == TagExist) {
+			db.UpdateFileEntry(curFile.GetFullPath(), (int)time(NULL));
+		}
+
 		if ( i % 50 == 0 ) {
 			// update the progress bar
 			if (!prgDlg.Update(i, wxT("Committing..."))) {
@@ -1281,7 +1375,7 @@ bool TagsManager::IsTypeAndScopeExists(wxString &typeName, wxString &scope)
 	if (iter != m_typeScopeCache.end()) {
 		return iter->second;
 	}
-	
+
 	// First try the fast query to save some time
 	if(m_workspaceDatabase->IsTypeAndScopeExistLimitOne(typeName, scope)) {
 		//wxLogMessage(wxT("Type Exist! Skipping!"));
@@ -1319,19 +1413,19 @@ bool TagsManager::GetDerivationList(const wxString &path, std::vector<wxString>
 			wxString inherits = tok.GetNextToken();
 			wxString tagName = tag->GetName();
 			wxString tmpInhr = inherits;
-			
+
 			tagName.MakeLower();
 			tmpInhr.MakeLower();
-			
+
 			// Make sure that inherits != the current name or we will end up in an infinite loop
 			if(tmpInhr != tagName) {
-			
+
 				if (tag->GetScopeName() != wxT("<global>")) {
 					inherits = tag->GetScopeName() + wxT("::") + inherits;
 				}
 				derivationList.push_back(inherits);
 				GetDerivationList(inherits, derivationList);
-				
+
 			}
 		}
 	}
@@ -1375,16 +1469,17 @@ void TagsManager::TipsFromTags(const std::vector<TagEntryPtr> &tags, const wxStr
 
 			// add return value
 			tip.Clear();
-			
-			wxString retValue = t->GetReturnValue();
-			if(retValue.IsEmpty() == false) {
-				tip << retValue << wxT(" ");
+
+			wxString ret_value = GetFunctionReturnValueFromPattern(t);
+			if(ret_value.IsEmpty() == false) {
+				tip << ret_value << wxT(" ");
 
 			} else {
-				wxString ret_value = GetFunctionReturnValueFromPattern(t);
-				if (ret_value.IsEmpty() == false) {
-					tip << ret_value << wxT(" ");
+				wxString retValue = t->GetReturnValue();
+				if(retValue.IsEmpty() == false) {
+					tip << retValue << wxT(" ");
 				}
+
 			}
 			// add the scope
 			if (!t->IsScopeGlobal()) {
@@ -1398,6 +1493,9 @@ void TagsManager::TipsFromTags(const std::vector<TagEntryPtr> &tags, const wxStr
 			tip << NormalizeFunctionSig(t->GetSignature(), Normalize_Func_Name | Normalize_Func_Default_value);
 		}
 
+		// remove any extra spaces from the tip
+		while (tip.Replace(wxT("  "), wxT(" "))) {}
+
 		// prepend any comment if exists
 		tips.push_back(tip);
 	}
@@ -1422,7 +1520,7 @@ void TagsManager::GetFunctionTipFromTags(const std::vector<TagEntryPtr> &tags, c
 			// collect each signature only once, we do this by using
 			// map
 			tipsMap[tip] = t;
-			
+
 		} else if (t->IsClass()) {
 
 			// this tag is a class declaration that matches the word
@@ -1711,21 +1809,16 @@ wxString TagsManager::FormatFunction(TagEntryPtr tag, size_t flags, const wxStri
 		body << wxT("virtual ");
 	}
 
-	if (foo.m_retrunValusConst.empty() == false) {
-		body << _U(foo.m_retrunValusConst.c_str()) << wxT(" ");
-	}
+	wxString ret_value = GetFunctionReturnValueFromPattern(tag);
+	if(ret_value.IsEmpty() == false) {
+		body << ret_value << wxT(" ");
 
-	if (foo.m_returnValue.m_typeScope.empty() == false) {
-		body << _U(foo.m_returnValue.m_typeScope.c_str()) << wxT("::");
-	}
-
-	if (foo.m_returnValue.m_type.empty() == false) {
-		body << _U(foo.m_returnValue.m_type.c_str());
-		if (foo.m_returnValue.m_templateDecl.empty() == false) {
-			body << wxT("<") << _U(foo.m_returnValue.m_templateDecl.c_str()) << wxT(">");
+	} else {
+		wxString retValue = tag->GetReturnValue();
+		if(retValue.IsEmpty() == false) {
+			body << retValue << wxT(" ");
 		}
-		body << _U(foo.m_returnValue.m_starAmp.c_str());
-		body << wxT(" ");
+
 	}
 
 	if (flags & FunctionFormat_Impl) {
@@ -1738,12 +1831,23 @@ wxString TagsManager::FormatFunction(TagEntryPtr tag, size_t flags, const wxStri
 		}
 	}
 
+	// Build the flags required by the NormalizeFunctionSig() method
+	size_t tmpFlags(0);
 	if ( flags & FunctionFormat_Impl ) {
-		body << tag->GetName() << NormalizeFunctionSig( tag->GetSignature(), Normalize_Func_Name | Normalize_Func_Reverse_Macro);
+		tmpFlags |= Normalize_Func_Name | Normalize_Func_Reverse_Macro;
 	} else {
-		body << tag->GetName() << NormalizeFunctionSig( tag->GetSignature(), Normalize_Func_Name | Normalize_Func_Reverse_Macro | Normalize_Func_Default_value );
+		tmpFlags |= Normalize_Func_Name | Normalize_Func_Reverse_Macro | Normalize_Func_Default_value;
 	}
 
+	if(flags & FunctionFormat_Arg_Per_Line)
+		tmpFlags |= Normalize_Func_Arg_Per_Line;
+
+	if(flags & FunctionFormat_Arg_Per_Line)
+		body << wxT("\n");
+
+	body << tag->GetName();
+	body << NormalizeFunctionSig( tag->GetSignature(), tmpFlags);
+
 	if ( foo.m_isConst ) {
 		body << wxT(" const");
 	}
@@ -1754,6 +1858,11 @@ wxString TagsManager::FormatFunction(TagEntryPtr tag, size_t flags, const wxStri
 		body << wxT(";\n");
 	}
 
+	// convert \t to spaces
+	body.Replace(wxT("\t"), wxT(" "));
+
+	// remove any extra spaces from the tip
+	while (body.Replace(wxT("  "), wxT(" "))) {}
 	return body;
 }
 
@@ -1939,7 +2048,7 @@ wxString TagsManager::NormalizeFunctionSig(const wxString &sig, size_t flags, st
 {
 	std::map<std::string, std::string> ignoreTokens = GetCtagsOptions().GetTokensMap();
 	std::map<std::string, std::string> reverseTokens;
-	
+
 	if(flags & Normalize_Func_Reverse_Macro)
 		reverseTokens = GetCtagsOptions().GetTokensReversedMap();
 
@@ -1955,6 +2064,9 @@ wxString TagsManager::NormalizeFunctionSig(const wxString &sig, size_t flags, st
 	if (paramLen) {
 		paramLen->clear();
 	}
+	if(flags & Normalize_Func_Arg_Per_Line && li.size()) {
+		str_output << wxT("\n    ");
+	}
 
 	VariableList::iterator iter = li.begin();
 	for ( ; iter != li.end() ; iter++) {
@@ -1993,14 +2105,13 @@ wxString TagsManager::NormalizeFunctionSig(const wxString &sig, size_t flags, st
 		if (v.m_rightSideConst.empty() == false) {
 			str_output << wxT(" ") << _U(v.m_rightSideConst.c_str());
 		}
-		
+
 		if (v.m_name.empty() == false && (flags & Normalize_Func_Name)) {
 			str_output << wxT(" ") << _U(v.m_name.c_str());
 		} else if ( v.m_isEllipsis ) {
 			str_output << wxT(" ...");
 		}
 
-
 		if (v.m_arrayBrackets.empty() == false) {
 			str_output << wxT(" ") << _U(v.m_arrayBrackets.c_str());
 		}
@@ -2014,6 +2125,9 @@ wxString TagsManager::NormalizeFunctionSig(const wxString &sig, size_t flags, st
 			paramLen->push_back(std::pair<int, int>(start_offset, str_output.length() - start_offset));
 		}
 		str_output << wxT(", ");
+		if(flags & Normalize_Func_Arg_Per_Line && li.size()) {
+			str_output << wxT("\n    ");
+		}
 	}
 
 	if (li.empty() == false) {
@@ -2416,3 +2530,58 @@ void TagsManager::SetProjectPaths(const wxArrayString& paths)
 	m_projectPaths.Clear();
 	m_projectPaths = paths;
 }
+
+void TagsManager::GetDereferenceOperator(const wxString& scope, std::vector<TagEntryPtr>& tags)
+{
+	std::vector<wxString> derivationList;
+
+	//add this scope as well to the derivation list
+	wxString _scopeName = DoReplaceMacros( scope );
+	derivationList.push_back(_scopeName);
+	GetDerivationList(_scopeName, derivationList);
+
+	//make enough room for max of 500 elements in the vector
+	for (size_t i=0; i<derivationList.size(); i++) {
+		wxString tmpScope(derivationList.at(i));
+		tmpScope = DoReplaceMacros(tmpScope);
+
+		GetDatabase()->GetDereferenceOperator(tmpScope, tags);
+		if(tags.size()) {
+
+			// No need to further check
+			break;
+
+		}
+	}
+}
+
+void TagsManager::GetSubscriptOperator(const wxString& scope, std::vector<TagEntryPtr>& tags)
+{
+	std::vector<wxString> derivationList;
+
+	//add this scope as well to the derivation list
+	wxString _scopeName = DoReplaceMacros( scope );
+	derivationList.push_back(_scopeName);
+	GetDerivationList(_scopeName, derivationList);
+
+	//make enough room for max of 500 elements in the vector
+	for (size_t i=0; i<derivationList.size(); i++) {
+		wxString tmpScope(derivationList.at(i));
+		tmpScope = DoReplaceMacros(tmpScope);
+
+		GetDatabase()->GetSubscriptOperator(scope, tags);
+		if(tags.size()) {
+
+			// No need to further check
+			break;
+
+		}
+	}
+}
+
+void TagsManager::ClearAllCaches()
+{
+	m_cachedFile.Clear();
+	m_cachedFileFunctionsTags.clear();
+	m_workspaceDatabase->ClearCache();
+}
