@@ -25,8 +25,8 @@ int main()
 	char *buf = loadFile("test.h");
 
 	//print the scope name
-	//testScopeParser(buf);
-	testVarParser(buf);
+	testScopeParser(buf);
+	//testVarParser(buf);
 	//testExprParser(buf);
 	//testFuncParser(buf);
 	//testTypedefParser(buf);
