@@ -18,8 +18,11 @@ public:
 	std::string     m_starAmp;
 	int             m_lineno;
 	bool            m_isConst;
+	std::string     m_rightSideConst;
 	std::string     m_defaultValue;	// used mainly for function arguments with default values foo(int = 0);
 	std::string     m_arrayBrackets;
+	bool            m_isEllipsis;
+	bool            m_isBasicType;
 
 public:
 	Variable();
