@@ -219,20 +219,26 @@ bool DbgCmdHandlerAsyncCmd::ProcessOutput(const wxString &line)
 	//completed:
 	//-exec-step, -exec-stepi
 	//-exec-next, -exec-nexti
-	wxStringTokenizer tkz(line, wxT(","));
-	if (tkz.HasMoreTokens()) {
-		tkz.NextToken();//skip *stopped
-	} else {
-		return false;
+
+	// Get the reason
+	std::vector<std::map<std::string, std::string> > children;
+	gdbParseListChildren(line.mb_str(wxConvUTF8).data(), children);
+
+
+	for (size_t i=0; i<children.size(); i++) {
+		std::map<std::string, std::string> attr = children.at(i);
+		std::map<std::string, std::string >::const_iterator iter;
+
+		iter = attr.find("reason");
+		if ( iter != attr.end() ) {
+			reason = wxString(iter->second.c_str(), wxConvUTF8);
+			wxRemoveQuotes( reason );
+			break;
+		}
 	}
-	//get the reason
-	if (tkz.HasMoreTokens()) {
-		reason = tkz.NextToken();
-		reason = reason.AfterFirst(wxT('"'));
-		reason = reason.BeforeLast(wxT('"'));
-	} else {
+
+	if(reason.IsEmpty())
 		return false;
-	}
 
 	//Note:
 	//This might look like a stupid if-else, since all taking
@@ -241,6 +247,7 @@ bool DbgCmdHandlerAsyncCmd::ProcessOutput(const wxString &line)
 	if (reason == wxT("end-stepping-range")) {
 		//just notify the container that we got control back from debugger
 		m_observer->UpdateGotControl(DBG_END_STEPPING);
+
 	} else if ((reason == wxT("breakpoint-hit")) || (reason == wxT("watchpoint-trigger"))) {
 		static wxRegEx reFuncName(wxT("func=\"([a-zA-Z!_0-9]+)\""));
 
@@ -262,6 +269,7 @@ bool DbgCmdHandlerAsyncCmd::ProcessOutput(const wxString &line)
 
 		// Notify the container that we got control back from debugger
 		m_observer->UpdateGotControl(DBG_BP_HIT);
+
 		// Now discover which bp was hit. Fortunately, that's in the next token: bkptno="12"
 		// Except that it no longer is in gdb 7.0. It's now: ..disp="keep",bkptno="12". So:
 		static wxRegEx reGetBreakNo(wxT("bkptno=\"([0-9]+)\""));
@@ -269,7 +277,25 @@ bool DbgCmdHandlerAsyncCmd::ProcessOutput(const wxString &line)
 			wxString number = reGetBreakNo.GetMatch(line, 1);
 			long id;
 			if (number.ToLong(&id)) {
-				m_observer->UpdateBpHit((int)id);
+				if(id != wxNOT_FOUND && m_gdb->m_internalBpId == id) {
+
+					m_observer->UpdateAddLine(wxString::Format(wxT("Internal breakpoint was hit (id=%d), Applying user breakpoints and continuing"), m_gdb->m_internalBpId));
+
+					// This is an internal breakpoint ID
+					m_gdb->m_internalBpId = wxNOT_FOUND;
+
+					// Apply the breakpoints
+					m_gdb->SetBreakpoints();
+
+					// Continue running
+					m_gdb->Continue();
+
+				} else {
+
+					// User breakpoint
+					m_observer->UpdateBpHit((int)id);
+
+				}
 			}
 		}
 
@@ -296,7 +322,7 @@ bool DbgCmdHandlerAsyncCmd::ProcessOutput(const wxString &line)
 
 		} else if (signame == wxT("SIGTRAP")) {
 			m_observer->UpdateGotControl(DBG_RECV_SIGNAL_SIGTRAP);
-			
+
 		} else {
 			//default
 			m_observer->UpdateGotControl(DBG_RECV_SIGNAL);
@@ -826,10 +852,7 @@ bool DbgCmdBreakList::ProcessOutput(const wxString& line)
 		li.push_back( breakpoint );
 	}
 
-	// We now have a vector of bps, each containing its debugger_id and ignore-count.
-	// Pass the vector to the breakpoints manager to be reconciled
-	if( li.empty() == false )
-		m_observer->ReconcileBreakpoints(li);
+	m_observer->ReconcileBreakpoints(li);
 	return true;
 }
 
@@ -1149,12 +1172,33 @@ bool DbgCmdEvalVarObj::ProcessOutput(const wxString& line)
 		if ( display_line.IsEmpty() == false && display_line != wxT("{...}")) {
 			DebuggerEvent e;
 			e.m_updateReason = DBG_UR_EVALVARIABLEOBJ;
-			e.m_expression = m_variable;
-			e.m_evaluated = display_line;
-			e.m_userReason = m_userReason;
+			e.m_expression    = m_variable;
+			e.m_evaluated     = display_line;
+			e.m_userReason    = m_userReason;
+			e.m_displayFormat = m_displayFormat;
 			m_observer->DebuggerUpdate( e );
 		}
 		return true;
 	}
 	return false;
 }
+
+bool DbgFindMainBreakpointIdHandler::ProcessOutput(const wxString& line)
+{
+	// so the breakpoint ID will come in form of
+	// ^done,bkpt={number="2"....
+	static wxRegEx reBreak   (wxT("done,bkpt={number=\"([0-9]+)\""));
+	wxString number;
+	long     breakpointId(wxNOT_FOUND);
+
+	reBreak.Matches(line);
+	number = reBreak.GetMatch(line, 1);
+	if (number.IsEmpty() == false) {
+		if (number.ToLong(&breakpointId)) {
+			// for debugging purpose
+			m_observer->UpdateAddLine(wxString::Format(wxT("Storing internal breakpoint ID=%d"), breakpointId), true);
+			m_debugger->SetInternalMainBpID( breakpointId );
+		}
+	}
+	return true;
+}
