@@ -83,6 +83,7 @@ ExternalToolsPlugin::ExternalToolsPlugin(IManager *manager)
 	topWin = m_mgr->GetTheApp();
 
 	topWin->Connect(XRCID("stop_external_tool"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(ExternalToolsPlugin::OnStopExternalTool), NULL, (wxEvtHandler*)this);
+	topWin->Connect(34733,                       wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(ExternalToolsPlugin::OnRecreateTB), NULL, (wxEvtHandler*)this);
 	topWin->Connect(XRCID("stop_external_tool"), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(ExternalToolsPlugin::OnStopExternalToolUI), NULL, (wxEvtHandler*)this);
 
 	for (int i=0; i<MAX_TOOLS; i++) {
@@ -96,6 +97,7 @@ ExternalToolsPlugin::~ExternalToolsPlugin()
 {
 	topWin->Disconnect(XRCID("external_tools_settings"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(ExternalToolsPlugin::OnSettings), NULL, (wxEvtHandler*)this);
 	topWin->Disconnect(XRCID("stop_external_tool"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(ExternalToolsPlugin::OnStopExternalTool), NULL, (wxEvtHandler*)this);
+	topWin->Disconnect(34733,                       wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(ExternalToolsPlugin::OnRecreateTB), NULL, (wxEvtHandler*)this);
 	topWin->Disconnect(XRCID("stop_external_tool"), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(ExternalToolsPlugin::OnStopExternalToolUI), NULL, (wxEvtHandler*)this);
 
 	for (int i=0; i<MAX_TOOLS; i++) {
@@ -200,11 +202,18 @@ void ExternalToolsPlugin::OnSettings(wxCommandEvent& e)
 		data.SetTools(dlg.GetTools());
 		m_mgr->GetConfigTool()->WriteObject(wxT("ExternalTools"), &data);
 
-		DoRecreateToolbar();
-		DoCreatePluginMenu();
+		wxCommandEvent evt(wxEVT_COMMAND_MENU_SELECTED, 34733);
+		wxPostEvent(this, evt);
 	}
 }
 
+void ExternalToolsPlugin::OnRecreateTB(wxCommandEvent &e)
+{
+	wxUnusedVar(e);
+	DoRecreateToolbar();
+	DoCreatePluginMenu();
+}
+
 void ExternalToolsPlugin::OnLaunchExternalTool(wxCommandEvent& e)
 {
 	ExternalToolsData inData;
@@ -318,10 +327,11 @@ void ExternalToolsPlugin::OnStopExternalToolUI(wxUpdateUIEvent& e)
 
 void ExternalToolsPlugin::DoCreatePluginMenu()
 {
+	const int MENU_ID = 28374;
 	if ( m_parentMenu ) {
 		// destroy the old menu entries
-		if ( m_parentMenu->FindItem(58374) ) {
-			m_parentMenu->Destroy(58374);
+		if ( m_parentMenu->FindItem(MENU_ID) ) {
+			m_parentMenu->Destroy(MENU_ID);
 		}
 
 		wxMenu *menu = new wxMenu();
@@ -340,7 +350,7 @@ void ExternalToolsPlugin::DoCreatePluginMenu()
 			menu->Append(item);
 		}
 
-		m_parentMenu->Append(58374, wxT("External Tools"), menu);
+		m_parentMenu->Append(MENU_ID, wxT("External Tools"), menu);
 		topWin->Connect(XRCID("external_tools_settings"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(ExternalToolsPlugin::OnSettings), NULL, (wxEvtHandler*)this);
 	}
 }
