@@ -210,7 +210,7 @@ public:
 
 		bp_type = BP_type_break;
 		lineno = line;
-		file = filename.IsEmpty() ? wxT("") : fn.GetFullPath();
+		file = filename.IsEmpty() ? wxString() : fn.GetFullPath();
 		internal_id = int_id;
 		debugger_id = ext_id;
 	}
@@ -620,6 +620,11 @@ public:
 	 * \brief set break point at given file and line, or function
 	 */
 	virtual bool Break(const BreakpointInfo& bp) = 0;
+	/**
+	 * @brief restart the debuggin session. (similar to 'run' command on GDB)
+	 * @return true on success false otherwise
+	 */
+	virtual bool Restart() = 0;
 	/**
 	 * \brief remove breakpoint by its ID
 	 */
