@@ -30,6 +30,7 @@
 #include <vector>
 #include <map>
 #include "entry.h"
+#include "stringhighlighterjob.h"
 #include "cl_calltip.h"
 #include "wx/filename.h"
 #include "findreplacedlg.h"
@@ -137,7 +138,11 @@ class LEditor : public wxScintilla, public IEditor
 	clEditorTipWindow*                          m_functionTip;
 	wxChar                                      m_lastCharEntered;
 	int                                         m_lastCharEnteredPos;
-//	DisplayVariableDlg*                         m_debuggerTip;
+
+public:
+	static bool                                 m_ccShowPrivateMembers;
+	static bool                                 m_ccShowItemsComments;
+	static bool                                 m_ccInitialized;
 
 public:
 	static FindReplaceData &GetFindReplaceData() {
@@ -155,10 +160,6 @@ public:
 		return m_functionTip;
 	}
 
-//	DisplayVariableDlg *GetDebuggerTip() {
-//		return m_debuggerTip;
-//	}
-
 public:
 	/// Construct a LEditor object
 	LEditor(wxWindow* parent);
@@ -190,6 +191,14 @@ public:
 
 	void CompleteWord();
 
+	/**
+	 * \brief chage the case of the current selection. If selection is empty,
+	 * change the selection of the character to the right of the cart. In case of changing
+	 * the char to the right, move the caret to the right as well.
+	 * \param toLower change to lower case.
+	 */
+	void ChangeCase(bool toLower);
+
 	// set this editor file name
 	void SetFileName(const wxFileName &name) {
 		m_fileName = name;
@@ -561,11 +570,40 @@ public:
 	virtual int WordEndPos (int pos, bool onlyWordCharacters);
 
 	/**
-	 * Insert text to the editor and keeping the indentation
+	 * Prepend the indentation level found at line at 'pos' to each line in the input string
 	 * \param text text to enter
 	 * \param pos position to insert the text
+	 * \param flags formatting flags
 	 */
-	virtual wxString FormatTextKeepIndent(const wxString &text, int pos);
+	virtual wxString FormatTextKeepIndent(const wxString &text, int pos, size_t flags = 0);
+
+
+	/**
+	 * @brief return the line numebr containing 'pos'
+	 * @param pos the position
+	 */
+	virtual int LineFromPos(int pos);
+
+	/**
+	 * @brief return the start pos of line nummber
+	 * @param line the line number
+	 * @return line nummber or 0 if the document is empty
+	 */
+	virtual int PosFromLine(int line);
+
+	/**
+	 * @brief return the END position of 'line'
+	 * @param line the line number
+	 */
+	virtual int LineEnd(int line);
+
+	/**
+	 * @brief return text from a given pos -> endPos
+	 * @param startPos
+	 * @param endPos
+	 * @return
+	 */
+	virtual wxString GetTextRange(int startPos, int endPos);
 
 	//----------------------------------------------------------------------------
 	//----------------------------------------------------------------------------
@@ -583,18 +621,20 @@ public:
 	}
 
 	wxString GetEolString();
+	void HighlightWord(StringHighlightOutput *highlightOutput);
 
 private:
 	void FillBPtoMarkerArray();
 	BPtoMarker GetMarkerForBreakpt(enum BreakpointType bp_type);
 	void SetProperties();
 	void DefineMarker(int marker, int markerType, wxColor fore, wxColor back);
-	void SetLineNumberWidth();
 	bool SaveToFile(const wxFileName &fileName);
 	void BraceMatch(const bool& bSelRegion);
 	void BraceMatch(long pos);
 	void DoHighlightWord();
 	void DoSetStatusMessage(const wxString &msg, int col);
+	bool IsOpenBrace (int position);
+	bool IsCloseBrace(int position);
 
 	// Conevert FindReplaceDialog flags to wxSD flags
 	size_t SearchFlags(const FindReplaceData &data);
@@ -633,7 +673,6 @@ private:
 	void OnDbgCustomWatch(wxCommandEvent &event);
 	void OnDragStart(wxScintillaEvent &e);
 	void OnDragEnd(wxScintillaEvent &e);
-	void OnHighlightThread(wxCommandEvent &e);
 	void DoSetCaretAt(long pos);
 };
 
