@@ -25,6 +25,7 @@
 
 
 #include "pluginmanager.h"
+#include "clang_code_completion.h"
 #include "drawingutils.h"
 #include "buildtabsettingsdata.h"
 #include "cl_editor_tip_window.h"
@@ -495,165 +496,6 @@ void ContextCpp::RemoveDuplicates(std::vector<TagEntryPtr>& src, std::vector<Tag
 	}
 }
 
-wxString ContextCpp::GetExpression(long pos, bool onlyWord, LEditor *editor, bool forCC)
-{
-	bool cont(true);
-	int depth(0);
-
-	LEditor *ctrl(NULL);
-	if (!editor) {
-		ctrl = &GetCtrl();
-	} else {
-		ctrl = editor;
-	}
-
-	int position( pos );
-	int at(position);
-	bool prevGt(false);
-	bool prevColon(false);
-	while (cont && depth >= 0) {
-		wxChar ch =ctrl->PreviousChar(position, at, true);
-		position = at;
-		//Eof?
-		if (ch == 0) {
-			at = 0;
-			break;
-		}
-
-		//Comment?
-		int style = ctrl->GetStyleAt(pos);
-		if (style == wxSCI_C_COMMENT				||
-		        style == wxSCI_C_COMMENTLINE			||
-		        style == wxSCI_C_COMMENTDOC				||
-		        style == wxSCI_C_COMMENTLINEDOC			||
-		        style == wxSCI_C_COMMENTDOCKEYWORD		||
-		        style == wxSCI_C_COMMENTDOCKEYWORDERROR ||
-		        style == wxSCI_C_STRING					||
-		        style == wxSCI_C_STRINGEOL				||
-		        style == wxSCI_C_CHARACTER) {
-			continue;
-		}
-
-		switch (ch) {
-		case wxT(';'):
-						// dont include this token
-						at = ctrl->PositionAfter(at);
-			cont = false;
-			prevColon = false;
-			break;
-		case wxT('-'):
-						if (prevGt) {
-					prevGt = false;
-					//if previous char was '>', we found an arrow so reduce the depth
-					//which was increased
-					depth--;
-				} else {
-					if (depth <= 0) {
-						//dont include this token
-						at =ctrl->PositionAfter(at);
-						cont = false;
-					}
-				}
-			prevColon = false;
-			break;
-		case wxT(' '):
-					case wxT('\n'):
-						case wxT('\v'):
-							case wxT('\t'):
-								case wxT('\r'):
-										prevGt = false;
-			prevColon = false;
-			if (depth <= 0) {
-				cont = false;
-				break;
-			}
-			break;
-		case wxT('{'):
-					case wxT('='):
-							prevGt = false;
-			prevColon = false;
-			cont = false;
-			break;
-		case wxT('('):
-					case wxT('['):
-							depth--;
-			prevGt = false;
-			prevColon = false;
-			if (depth < 0) {
-				//dont include this token
-				at =ctrl->PositionAfter(at);
-				cont = false;
-			}
-			break;
-		case wxT(','):
-					case wxT('*'):
-						case wxT('&'):
-							case wxT('!'):
-								case wxT('~'):
-									case wxT('+'):
-										case wxT('^'):
-											case wxT('|'):
-												case wxT('%'):
-													case wxT('?'):
-															prevGt = false;
-			prevColon = false;
-			if (depth <= 0) {
-
-				//dont include this token
-				at =ctrl->PositionAfter(at);
-				cont = false;
-			}
-			break;
-		case wxT('>'):
-						prevGt = true;
-			prevColon = false;
-			depth++;
-			break;
-		case wxT('<'):
-						prevGt = false;
-			prevColon = false;
-			depth--;
-			if (depth < 0) {
-
-				//dont include this token
-				at =ctrl->PositionAfter(at);
-				cont = false;
-			}
-			break;
-		case wxT(')'):
-					case wxT(']'):
-							prevGt = false;
-			prevColon = false;
-			depth++;
-			break;
-		default:
-			prevGt = false;
-			prevColon = false;
-			break;
-		}
-	}
-
-	if (at < 0) at = 0;
-	wxString expr = ctrl->GetTextRange(at, pos);
-	if ( !forCC ) {
-		// If we do not require the expression for CodeCompletion
-		// return the un-touched buffer
-		return expr;
-	}
-
-	//remove comments from it
-	CppScanner sc;
-	sc.SetText(_C(expr));
-	wxString expression;
-	int type=0;
-	while ( (type = sc.yylex()) != 0 ) {
-		wxString token = _U(sc.YYText());
-		expression += token;
-		expression += wxT(" ");
-	}
-	return expression;
-}
-
 wxString ContextCpp::GetWordUnderCaret()
 {
 	LEditor &rCtrl = GetCtrl();
@@ -864,8 +706,10 @@ void ContextCpp::CompleteWord()
 	DoSetProjectPaths();
 	if (mgr->WordCompletionCandidates(rCtrl.GetFileName(), lineNum, expr, text, word, candidates)) {
 		DisplayCompletionBox(candidates, word, false);
+	} else {
+		// Incase code completion fails, use clang to complete
+		ClangCodeCompletion::Instance()->CodeComplete( &rCtrl );
 	}
-
 }
 
 void ContextCpp::DisplayCompletionBox(const std::vector<TagEntryPtr> &tags, const wxString &word, bool showFullDecl)
@@ -2080,11 +1924,13 @@ void ContextCpp::AutoAddComment()
 	int curpos = rCtrl.GetCurrentPos();
 	int line = rCtrl.LineFromPosition(curpos);
 	int cur_style = rCtrl.GetStyleAt(curpos);
+    wxString text = rCtrl.GetLine(line-1).Trim(false);
 
 	bool dontadd = false;
 	switch (cur_style) {
 	case wxSCI_C_COMMENTLINE:
-		dontadd = rCtrl.GetLine(line-1).Trim().Trim(false) == wxT("//") || !data.GetContinueCppComment();
+    case wxSCI_C_COMMENTLINEDOC:
+		dontadd = ! text.StartsWith( wxT("//") ) || !data.GetContinueCppComment();
 		break;
 	case wxSCI_C_COMMENT:
 	case wxSCI_C_COMMENTDOC:
@@ -2102,9 +1948,38 @@ void ContextCpp::AutoAddComment()
 	wxString toInsert;
 	switch (cur_style) {
 	case wxSCI_C_COMMENTLINE:
-		if (rCtrl.GetStyleAt(rCtrl.PositionAfter(curpos)) != wxSCI_C_COMMENTLINE) {
-			toInsert = wxT("// ");
-		}
+    case wxSCI_C_COMMENTLINEDOC:
+        {
+            if ( text.StartsWith( wxT("//") ) )
+            {
+                // try to parse the comment text and indentation
+                unsigned i = (text.Length() > 2 && text[2] == wxT('!')) ? 3 : 2; // support "//!" for doxygen
+                i = text.find_first_not_of( wxT('/'), i );
+                i = text.find_first_not_of( wxT(" \t"), i );
+                if (i == wxString::npos)
+                    i = text.Length()-1;
+                // we want to avoid duplicating line-long comments such as those
+                // that sometime start a comment block; if there's something more on
+                // the line, after our match, then we can assume that we do not have
+                // a line-long comment; we do want to duplicate the comments on
+                // otherwise blank lines, however, to allow comment blocks with
+                // blank lines in the comment text, so we will still accept the
+                // match if it is less than half the typical line length
+                // (i.e. 80/2=40) (a guesstimate that it's not a line-long
+                // comment); otherwise, we'll use a default value
+                if ( i < text.Length()-1 || i < 40 )
+                {
+                    toInsert = text.substr(0,i);
+                }
+                else
+                {
+                    if (cur_style == wxSCI_C_COMMENTLINEDOC && i >= 3)
+                        toInsert = text.substr(0,3) + wxT(" ");
+                    else
+                        toInsert = wxT("// ");
+                }
+            }
+        }
 		break;
 	case wxSCI_C_COMMENT:
 	case wxSCI_C_COMMENTDOC:
@@ -2589,9 +2464,10 @@ void ContextCpp::DoCodeComplete(long pos)
 		DoSetProjectPaths();
 		if (TagsManagerST::Get()->AutoCompleteCandidates(rCtrl.GetFileName(), line, expr, text, candidates)) {
 			DisplayCompletionBox(candidates, wxEmptyString, showFullDecl);
+		} else {
+			ClangCodeCompletion::Instance()->CodeComplete( &rCtrl );
 		}
 	}
-
 }
 
 int ContextCpp::GetHyperlinkRange(int pos, int &start, int &end)
@@ -2734,7 +2610,7 @@ void ContextCpp::OnGotoNextFunction(wxCommandEvent& event)
 
 void ContextCpp::OnCallTipClick(wxScintillaEvent& e)
 {
-	wxUnusedVar(e);
+	e.Skip();
 }
 
 void ContextCpp::OnCalltipCancel()
@@ -2848,3 +2724,171 @@ void ContextCpp::DoSetProjectPaths()
 	}
 	TagsManagerST::Get()->SetProjectPaths( projectPaths );
 }
+
+wxString ContextCpp::GetCurrentScopeName()
+{
+	TagEntryPtr tag = TagsManagerST::Get()->FunctionFromFileLine(GetCtrl().GetFileName(), GetCtrl().GetCurrentLine()+1);
+	if(tag) {
+		return tag->GetParent();
+	}
+	return wxEmptyString;
+}
+
+wxString ContextCpp::GetExpression(long pos, bool onlyWord, LEditor *editor, bool forCC)
+{
+	bool cont(true);
+	int depth(0);
+
+	LEditor *ctrl(NULL);
+	if (!editor) {
+		ctrl = &GetCtrl();
+	} else {
+		ctrl = editor;
+	}
+
+	int position( pos );
+	int at(position);
+	bool prevGt(false);
+	bool prevColon(false);
+	while (cont && depth >= 0) {
+		wxChar ch =ctrl->PreviousChar(position, at, true);
+		position = at;
+		//Eof?
+		if (ch == 0) {
+			at = 0;
+			break;
+		}
+
+		//Comment?
+		int style = ctrl->GetStyleAt(pos);
+		if (style == wxSCI_C_COMMENT				||
+		        style == wxSCI_C_COMMENTLINE			||
+		        style == wxSCI_C_COMMENTDOC				||
+		        style == wxSCI_C_COMMENTLINEDOC			||
+		        style == wxSCI_C_COMMENTDOCKEYWORD		||
+		        style == wxSCI_C_COMMENTDOCKEYWORDERROR ||
+		        style == wxSCI_C_STRING					||
+		        style == wxSCI_C_STRINGEOL				||
+		        style == wxSCI_C_CHARACTER) {
+			continue;
+		}
+
+		switch (ch) {
+		case wxT(';'):
+						// dont include this token
+						at = ctrl->PositionAfter(at);
+			cont = false;
+			prevColon = false;
+			break;
+		case wxT('-'):
+						if (prevGt) {
+					prevGt = false;
+					//if previous char was '>', we found an arrow so reduce the depth
+					//which was increased
+					depth--;
+				} else {
+					if (depth <= 0) {
+						//dont include this token
+						at =ctrl->PositionAfter(at);
+						cont = false;
+					}
+				}
+			prevColon = false;
+			break;
+		case wxT(' '):
+					case wxT('\n'):
+						case wxT('\v'):
+							case wxT('\t'):
+								case wxT('\r'):
+										prevGt = false;
+			prevColon = false;
+			if (depth <= 0) {
+				cont = false;
+				break;
+			}
+			break;
+		case wxT('{'):
+					case wxT('='):
+							prevGt = false;
+			prevColon = false;
+			cont = false;
+			break;
+		case wxT('('):
+					case wxT('['):
+							depth--;
+			prevGt = false;
+			prevColon = false;
+			if (depth < 0) {
+				//dont include this token
+				at =ctrl->PositionAfter(at);
+				cont = false;
+			}
+			break;
+		case wxT(','):
+					case wxT('*'):
+						case wxT('&'):
+							case wxT('!'):
+								case wxT('~'):
+									case wxT('+'):
+										case wxT('^'):
+											case wxT('|'):
+												case wxT('%'):
+													case wxT('?'):
+															prevGt = false;
+			prevColon = false;
+			if (depth <= 0) {
+
+				//dont include this token
+				at =ctrl->PositionAfter(at);
+				cont = false;
+			}
+			break;
+		case wxT('>'):
+						prevGt = true;
+			prevColon = false;
+			depth++;
+			break;
+		case wxT('<'):
+						prevGt = false;
+			prevColon = false;
+			depth--;
+			if (depth < 0) {
+
+				//dont include this token
+				at =ctrl->PositionAfter(at);
+				cont = false;
+			}
+			break;
+		case wxT(')'):
+					case wxT(']'):
+							prevGt = false;
+			prevColon = false;
+			depth++;
+			break;
+		default:
+			prevGt = false;
+			prevColon = false;
+			break;
+		}
+	}
+
+	if (at < 0) at = 0;
+	wxString expr = ctrl->GetTextRange(at, pos);
+	if ( !forCC ) {
+		// If we do not require the expression for CodeCompletion
+		// return the un-touched buffer
+		return expr;
+	}
+
+	//remove comments from it
+	CppScanner sc;
+	sc.SetText(_C(expr));
+	wxString expression;
+	int type=0;
+	while ( (type = sc.yylex()) != 0 ) {
+		wxString token = _U(sc.YYText());
+		expression += token;
+		expression += wxT(" ");
+	}
+	return expression;
+}
