@@ -6,8 +6,8 @@ EditorSettingsDockingWindows::EditorSettingsDockingWindows( wxWindow* parent )
 {
 	m_checkBoxHideOutputPaneOnClick->SetValue(EditorConfigST::Get()->GetOptions()->GetHideOutpuPaneOnUserClick());
 	m_checkBoxHideOutputPaneNotIfDebug->SetValue(EditorConfigST::Get()->GetOptions()->GetHideOutputPaneNotIfDebug());
-	m_checkBoxShowQuickFinder->SetValue(EditorConfigST::Get()->GetOptions()->GetShowQuickFinder());
-	
+	m_checkBoxFindBarAtBottom->SetValue(EditorConfigST::Get()->GetOptions()->GetFindBarAtBottom());
+	m_checkBoxOutputPaneCanDock->SetValue(EditorConfigST::Get()->GetOptions()->GetOutputPaneDockable());
 	m_checkBoxHideOutputPaneNotIfDebug->Connect( wxEVT_UPDATE_UI, wxUpdateUIEventHandler( EditorSettingsDockingWindows::OnHideOutputPaneNotIfDebugUI ), NULL, this );
 }
 
@@ -15,11 +15,11 @@ void EditorSettingsDockingWindows::Save(OptionsConfigPtr options)
 {
 	options->SetHideOutpuPaneOnUserClick( m_checkBoxHideOutputPaneOnClick->IsChecked() );
 	options->SetHideOutputPaneNotIfDebug( m_checkBoxHideOutputPaneNotIfDebug->IsChecked() );
-	options->SetShowQuickFinder( m_checkBoxShowQuickFinder->IsChecked() );
+	options->SetFindBarAtBottom( m_checkBoxFindBarAtBottom->IsChecked() );
+	options->SetOutputPaneDockable( m_checkBoxOutputPaneCanDock->IsChecked());
 }
 
 void EditorSettingsDockingWindows::OnHideOutputPaneNotIfDebugUI(wxUpdateUIEvent& event)
 {
 	event.Enable( m_checkBoxHideOutputPaneOnClick->IsChecked() );
 }
-
