@@ -39,7 +39,7 @@ class wxStaticText;
 #define wxFRD_SEARCHUP                      0x00000008
 #define wxFRD_WRAPSEARCH                    0x00000010
 #define wxFRD_SELECTIONONLY                 0x00000020
-#define wxFRD_USEFONTENCODING               0x00000040
+/*#define wxFRD_USEFONTENCODING               0x00000040*/
 #define wxFRD_DISPLAYSCOPE                  0x00000080
 #define wxFRD_SAVE_BEFORE_SEARCH            0x00000100
 
@@ -69,6 +69,9 @@ class FindReplaceData : public SerializedObject
 	wxArrayString  m_findString;
 	size_t         m_flags;
 	wxArrayString  m_searchPaths;
+	wxString       m_encoding;
+	wxArrayString  m_fileMask;
+	wxString       m_selectedMask;
 
 private:
 	void TruncateArray(wxArrayString &arr, size_t maxSize);
@@ -87,6 +90,12 @@ public:
 		m_flags = flags;
 	}
 
+	void SetSelectedMask(const wxString& selectedMask) {
+		this->m_selectedMask = selectedMask;
+	}
+	const wxString& GetSelectedMask() const {
+		return m_selectedMask;
+	}
 	wxArrayString &GetFindStringArr() {
 		return m_findString;
 	}
@@ -94,6 +103,18 @@ public:
 		return m_replaceString;
 	}
 
+	void SetEncoding(const wxString& encoding) {
+		this->m_encoding = encoding;
+	}
+	void SetFileMask(const wxArrayString& fileMask) {
+		this->m_fileMask = fileMask;
+	}
+	const wxString& GetEncoding() const {
+		return m_encoding;
+	}
+	const wxArrayString& GetFileMask() const {
+		return m_fileMask;
+	}
 	/**
 	 * \brief return the first find string on the array
 	 */
