@@ -29,6 +29,7 @@
 #include "frame.h"
 #include <wx/wupdlock.h>
 #include "manager.h"
+#include "clang_code_completion.h"
 #include "close_all_dlg.h"
 #include "filechecklist.h"
 #include "editor_config.h"
@@ -75,6 +76,7 @@ void MainBook::ConnectEvents()
 	m_book->Connect(wxEVT_COMMAND_BOOK_PAGE_CLOSING,         NotebookEventHandler(MainBook::OnPageClosing),  NULL, this);
 	m_book->Connect(wxEVT_COMMAND_BOOK_PAGE_CLOSED,          NotebookEventHandler(MainBook::OnPageClosed),   NULL, this);
 	m_book->Connect(wxEVT_COMMAND_BOOK_PAGE_CHANGED,         NotebookEventHandler(MainBook::OnPageChanged),  NULL, this);
+	m_book->Connect(wxEVT_COMMAND_BOOK_PAGE_CHANGING,        NotebookEventHandler(MainBook::OnPageChanging), NULL, this);
 	m_book->Connect(wxEVT_COMMAND_BOOK_PAGE_X_CLICKED,       NotebookEventHandler(MainBook::OnClosePage),    NULL, this);
 	m_book->Connect(wxEVT_COMMAND_BOOK_PAGE_MIDDLE_CLICKED,  NotebookEventHandler(MainBook::OnClosePage),    NULL, this);
 	m_book->Connect(wxEVT_COMMAND_BOOK_BG_DCLICK,            NotebookEventHandler(MainBook::OnMouseDClick),  NULL, this);
@@ -84,6 +86,9 @@ void MainBook::ConnectEvents()
 	wxTheApp->Connect(wxEVT_PROJ_FILE_REMOVED, wxCommandEventHandler(MainBook::OnProjectFileRemoved), NULL, this);
 	wxTheApp->Connect(wxEVT_WORKSPACE_CLOSED,  wxCommandEventHandler(MainBook::OnWorkspaceClosed),    NULL, this);
 	wxTheApp->Connect(wxEVT_DEBUG_ENDED,       wxCommandEventHandler(MainBook::OnDebugEnded),         NULL, this);
+
+	// Highlight Job
+	Connect(wxEVT_CMD_JOB_STATUS_VOID_PTR,         wxCommandEventHandler(MainBook::OnStringHighlight),      NULL, this);
 }
 
 MainBook::~MainBook()
@@ -100,6 +105,8 @@ MainBook::~MainBook()
 	wxTheApp->Disconnect(wxEVT_PROJ_FILE_REMOVED, wxCommandEventHandler(MainBook::OnProjectFileRemoved), NULL, this);
 	wxTheApp->Disconnect(wxEVT_WORKSPACE_CLOSED,  wxCommandEventHandler(MainBook::OnWorkspaceClosed),    NULL, this);
 	wxTheApp->Disconnect(wxEVT_DEBUG_ENDED,       wxCommandEventHandler(MainBook::OnDebugEnded),         NULL, this);
+
+	Disconnect(wxEVT_CMD_JOB_STATUS_VOID_PTR,         wxCommandEventHandler(MainBook::OnStringHighlight),      NULL, this);
 }
 
 void MainBook::OnMouseDClick(NotebookEvent& e)
@@ -111,9 +118,12 @@ void MainBook::OnMouseDClick(NotebookEvent& e)
 void MainBook::OnPageClosing(NotebookEvent &e)
 {
 	LEditor *editor = dynamic_cast<LEditor*>(m_book->GetPage(e.GetSelection()));
-	if (!editor) {
-		; // the page is not an editor
-	} else if (AskUserToSave(editor)) {
+	if (!editor)
+		return;
+	
+	ClangCodeCompletion::Instance()->CancelCodeComplete();
+		
+	if (AskUserToSave(editor)) {
 		SendCmdEvent(wxEVT_EDITOR_CLOSING, (IEditor*)editor);
 	} else {
 		e.Veto();
@@ -700,6 +710,8 @@ bool MainBook::CloseAll(bool cancellable)
 
 	// Delete the files without notifications (it will be faster)
 	wxWindowUpdateLocker locker(this);
+	ClangCodeCompletion::Instance()->CancelCodeComplete();
+	
 	m_book->DeleteAllPages(false);
 
 	// Since we got no more editors opened,
@@ -942,3 +954,27 @@ void MainBook::DoHandleFrameMenu(LEditor* editor)
 		}
 	}
 }
+
+void MainBook::OnStringHighlight(wxCommandEvent& e)
+{
+	StringHighlightOutput *result = reinterpret_cast<StringHighlightOutput*>( e.GetClientData() );
+	if(result) {
+
+		// Locate the editor
+		LEditor *editor = FindEditor( result->filename );
+		if(editor) {
+			editor->HighlightWord( result );
+		}
+		delete result;
+	}
+}
+
+void MainBook::OnPageChanging(NotebookEvent& e)
+{
+	LEditor *editor = GetActiveEditor();
+	if(editor) {
+		editor->HideCompletionBox();
+		editor->CallTipCancel();
+	}
+	e.Skip();
+}
