@@ -66,7 +66,7 @@ class Manager : public wxEvtHandler, public IDebuggerObserver
 	std::list<QueueCommand> m_buildQueue;
 	wxArrayString           m_dbgWatchExpressions;
 	wxFileName              m_codeliteLauncher;
-	DisplayVariableDlg       *m_displayVariableDlg;
+	DisplayVariableDlg     *m_watchDlg;
 
 protected:
 	Manager(void);
@@ -74,7 +74,7 @@ protected:
 
      //--------------------------- Global State -----------------------------
 public:
-	DisplayVariableDlg * GetDisplayVariableDialog();
+	DisplayVariableDlg *GetDebuggerTip();
 
  	const wxString &GetStarupDirectory() const { return m_startupDir; }
  	void SetStarupDirectory(const wxString &path) { m_startupDir = path; }
@@ -183,7 +183,7 @@ public:
 	 * Import a MS Solution file and open it in the editor
 	 * \param path path to the .sln file
 	 */
-	void ImportMSVSSolution(const wxString &path);
+	void ImportMSVSSolution(const wxString &path, const wxString &defaultCompiler);
 
 	/**
 	 * Remove the a project from the workspace
@@ -382,6 +382,8 @@ public:
   	 */
  	wxString GetProjectExecutionCommand(const wxString &projectName, wxString &wd, bool considerPauseWhenExecuting = true);
 
+	bool     DoFindDockInfo   (const wxString &saved_perspective, const wxString &dock_name, wxString &dock_info);
+
      //--------------------------- Top Level Pane Management -----------------------------
 public:
   	/**
@@ -404,6 +406,12 @@ public:
   	 */
  	void ShowDebuggerPane(bool commit = true);
 
+	/**
+	 * \brief toggle the output pane
+	 * \param hide show or hide
+	 */
+	void ToggleOutputPane(bool hide);
+
   	/**
  	 * Show the workspace pane and set focus to focusWin
  	 * \param focusWin tab name to set the focus
