@@ -80,7 +80,7 @@ void OutputTabWindow::InitStyle(wxScintilla *sci, int lexer, bool folding)
 
 	for(int i=0; i<=wxSCI_STYLE_DEFAULT; i++) {
 		sci->StyleSetBackground(i, wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW));
-		sci->StyleSetForeground(i, wxT("BLACK"));
+		sci->StyleSetForeground(i, DrawingUtils::GetTextCtrlTextColour());
 	}
 
 	wxFont defFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
@@ -175,11 +175,18 @@ void OutputTabWindow::CreateGUIControls()
 	              _("Repeat"));
 
 	m_tb->Realize();
-	mainSizer->Add(m_tb, 0, wxTOP|wxBOTTOM|wxEXPAND, 5);
 
+#ifdef __WXMAC__
 	m_sci = new wxScintilla(this);
 	InitStyle(m_sci, wxSCI_LEX_CONTAINER, false);
-	mainSizer->Add(m_sci, 1, wxEXPAND | wxALL, 1);
+	mainSizer->Add(m_sci, 1, wxEXPAND);
+	mainSizer->Add(m_tb, 0, wxEXPAND);
+#else
+	m_sci = new wxScintilla(this);
+	InitStyle(m_sci, wxSCI_LEX_CONTAINER, false);
+	mainSizer->Add(m_tb, 0, wxEXPAND);
+	mainSizer->Add(m_sci, 1, wxEXPAND);
+#endif
 
 	mainSizer->Layout();
 }
