@@ -35,7 +35,7 @@
 #include "plugindata.h"
 #include "keyboardmanager.h"
 
-class Notebook;
+class wxBookCtrlBase;
 class EnvironmentConfig;
 class JobQueue;
 class BuildSettingsConfig;
@@ -75,8 +75,8 @@ public:
 	virtual IConfigTool *          GetConfigTool();
 	virtual TreeItemInfo           GetSelectedTreeItemInfo(TreeType type);
 	virtual wxTreeCtrl *           GetTree(TreeType type);
-	virtual Notebook *             GetOutputPaneNotebook();
-    virtual Notebook *             GetWorkspacePaneNotebook();
+	virtual OutputPaneBook*        GetOutputPaneNotebook();
+	virtual Notebook *             GetWorkspacePaneNotebook();
 	virtual bool                   OpenFile(const wxString &fileName, const wxString &projectName = wxEmptyString, int lineno = wxNOT_FOUND);
 	virtual bool                   OpenFile(const BrowseRecord &rec);
 	virtual wxString               GetStartupDirectory() const;
@@ -101,8 +101,8 @@ public:
 	virtual IKeyboard *            GetKeyboardManager();
 	virtual bool                   CreateVirtualDirectory(const wxString& parentPath, const wxString& vdName);
 	virtual OptionsConfigPtr       GetEditorSettings();
-    virtual void                   FindAndSelect(const wxString& pattern, const wxString& name);
-    virtual TagEntryPtr            GetTagAtCaret(bool scoped, bool impl);
+	virtual void                   FindAndSelect(const wxString& pattern, const wxString& name);
+	virtual TagEntryPtr            GetTagAtCaret(bool scoped, bool impl);
 	virtual bool                   AllowToolbar();
 	virtual void                   SetStatusMessage(const wxString &msg, int col, int id);
 	virtual void                   PushQueueCommand(const QueueCommand &cmd);
@@ -113,13 +113,15 @@ public:
 	virtual wxString               GetProjectNameByFile( const wxString &fullPathFileName );
 	virtual BuildManager *         GetBuildManager();
 	virtual BuildSettingsConfig *  GetBuildSettingsConfigManager();
-    virtual bool                   ClosePage(const wxString &text);
-    virtual wxWindow *             FindPage(const wxString &text);
-    virtual bool                   AddPage(wxWindow *win, const wxString &text, const wxBitmap &bmp = wxNullBitmap, bool selected = false);
-    virtual bool                   SelectPage(wxWindow *win);
+	virtual bool                   ClosePage(const wxString &text);
+	virtual wxWindow *             FindPage(const wxString &text);
+	virtual bool                   AddPage(wxWindow *win, const wxString &text, const wxBitmap &bmp = wxNullBitmap, bool selected = false);
+	virtual bool                   SelectPage(wxWindow *win);
 	virtual NavMgr *               GetNavigationMgr();
 	virtual IEditor*               NewEditor();
-	
+	virtual IMacroManager*         GetMacrosManager();
+	virtual bool                   IsShutdownInProgress() const;
+
 	//------------------------------------
 	//End of IManager interface
 	//------------------------------------
