@@ -36,9 +36,11 @@ class QuickFindBar : public QuickFindBarBase
 protected:
 	void ShowReplaceControls(bool show = true);
 	void DoSearch(bool fwd, bool incr);
+	void DoMarkAll();
+
 	wxTextCtrl *GetFocusedControl();
 	void DoShowControls();
-	
+
 	// General events
 	void OnCopy         (wxCommandEvent  &e);
 	void OnPaste        (wxCommandEvent  &e);
@@ -61,12 +63,24 @@ protected:
 	void OnCheckBoxRegex( wxCommandEvent& event );
 	void OnCheckBoxWord ( wxCommandEvent& event );
 	void OnToggleReplaceControls( wxCommandEvent& event );
+	void OnToggleReplaceControlsUI(wxUpdateUIEvent& event);
+	void OnHighlightMatches(wxCommandEvent& event);
+	void OnHighlightMatchesUI(wxUpdateUIEvent& event);
+
+
+	void OnFindNext         (wxCommandEvent &e);
+	void OnFindPrevious     (wxCommandEvent &e);
+	void OnFindNextCaret    (wxCommandEvent &e);
+	void OnFindPreviousCaret(wxCommandEvent &e);
+
+protected:
+	bool DoShow(bool s, const wxString &findWhat);
 
 public:
 	QuickFindBar(wxWindow *parent, wxWindowID id = wxID_ANY);
 	int GetCloseButtonId();
 	bool Show(bool s = true);
-
+	bool Show(const wxString &findWhat);
 	wxScintilla *GetEditor() {
 		return m_sci;
 	}
