@@ -29,7 +29,7 @@
 #include "debuggermanager.h"
 #include "globals.h"
 
-SimpleTable::SimpleTable( wxWindow* parent )
+WatchesTable::WatchesTable( wxWindow* parent )
 		:
 		SimpleTableBase( parent )
 		, m_selectedId(wxNOT_FOUND)
@@ -38,18 +38,18 @@ SimpleTable::SimpleTable( wxWindow* parent )
 
 	//Load the right click menu
 	m_rclickMenu = wxXmlResource::Get()->LoadMenu(wxT("dbg_watch_rmenu"));
-	Connect(XRCID("del_expr"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( SimpleTable::OnDeleteWatch), NULL, this);
-	Connect(XRCID("del_expr_all"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( SimpleTable::OnDeleteAll), NULL, this);
-	Connect(XRCID("expand_expr"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( SimpleTable::OnMenuExpandExpr), NULL, this);
-	Connect(XRCID("edit_expr"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( SimpleTable::OnMenuEditExpr), NULL, this);
-	Connect(XRCID("copy_expr"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( SimpleTable::OnMenuCopyExpr), NULL, this);
-	Connect(XRCID("copy_both"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( SimpleTable::OnMenuCopyBoth), NULL, this);
-	Connect(XRCID("copy_value"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( SimpleTable::OnMenuCopyValue), NULL, this);
-	Connect(XRCID("dereference_expr"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( SimpleTable::OnMenuDerefExpr), NULL, this);
-	Connect(XRCID("add_watch"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( SimpleTable::OnNewWatch_Iternal), NULL, this);
+	Connect(XRCID("del_expr"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnDeleteWatch), NULL, this);
+	Connect(XRCID("del_expr_all"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnDeleteAll), NULL, this);
+	Connect(XRCID("expand_expr"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuExpandExpr), NULL, this);
+	Connect(XRCID("edit_expr"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuEditExpr), NULL, this);
+	Connect(XRCID("copy_expr"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuCopyExpr), NULL, this);
+	Connect(XRCID("copy_both"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuCopyBoth), NULL, this);
+	Connect(XRCID("copy_value"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuCopyValue), NULL, this);
+	Connect(XRCID("dereference_expr"),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnMenuDerefExpr), NULL, this);
+	Connect(XRCID("add_watch"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( WatchesTable::OnNewWatch_Iternal), NULL, this);
 }
 
-SimpleTable::~SimpleTable()
+WatchesTable::~WatchesTable()
 {
 	if (m_rclickMenu) {
 		delete m_rclickMenu;
@@ -57,31 +57,31 @@ SimpleTable::~SimpleTable()
 	}
 }
 
-void SimpleTable::Clear()
+void WatchesTable::Clear()
 {
 	m_listTable->DeleteAllItems();
 }
 
-void SimpleTable::InitTable()
+void WatchesTable::InitTable()
 {
 	//add two columns to the list ctrl
 	m_listTable->InsertColumn(0, wxT("Expression"));
 	m_listTable->InsertColumn(1, wxT("Value"));
 }
 
-void SimpleTable::OnItemActivated( wxListEvent& event )
+void WatchesTable::OnItemActivated( wxListEvent& event )
 {
 	m_selectedId = event.m_itemIndex;
 	DoShowMoreDetails(m_selectedId);
 }
 
-void SimpleTable::OnItemSelected( wxListEvent& event )
+void WatchesTable::OnItemSelected( wxListEvent& event )
 {
 	// TODO: Implement OnItemSelected
 	m_selectedId = event.m_itemIndex;
 }
 
-void SimpleTable::OnListKeyDown( wxListEvent& event )
+void WatchesTable::OnListKeyDown( wxListEvent& event )
 {
 	if (event.GetKeyCode() == WXK_DELETE || event.GetKeyCode() == WXK_NUMPAD_DELETE) {
 		//remove the entry
@@ -92,7 +92,7 @@ void SimpleTable::OnListKeyDown( wxListEvent& event )
 	}
 }
 
-void SimpleTable::OnItemRightClick(wxListEvent &event)
+void WatchesTable::OnItemRightClick(wxListEvent &event)
 {
 	wxUnusedVar(event);
 	if (m_rclickMenu) {
@@ -100,13 +100,13 @@ void SimpleTable::OnItemRightClick(wxListEvent &event)
 	}
 }
 
-void SimpleTable::OnItemDeSelected(wxListEvent &event)
+void WatchesTable::OnItemDeSelected(wxListEvent &event)
 {
 	m_selectedId = wxNOT_FOUND;
 	wxUnusedVar(event);
 }
 
-void SimpleTable::OnNewWatch(wxCommandEvent &event)
+void WatchesTable::OnNewWatch(wxCommandEvent &event)
 {
 	wxUnusedVar(event);
 	wxString expr = wxGetTextFromUser(wxT("Expression to watch:"), wxT("New watch"));
@@ -116,13 +116,13 @@ void SimpleTable::OnNewWatch(wxCommandEvent &event)
 	}
 }
 
-void SimpleTable::OnNewWatchUI(wxUpdateUIEvent &event)
+void WatchesTable::OnNewWatchUI(wxUpdateUIEvent &event)
 {
 	event.Enable(true);
 }
 
 
-void SimpleTable::OnDeleteAll(wxCommandEvent &event)
+void WatchesTable::OnDeleteAll(wxCommandEvent &event)
 {
 	wxUnusedVar(event);
 	if (m_listTable->GetItemCount()>0) {
@@ -131,12 +131,12 @@ void SimpleTable::OnDeleteAll(wxCommandEvent &event)
 	}
 }
 
-void SimpleTable::OnDeleteAllUI(wxUpdateUIEvent &event)
+void WatchesTable::OnDeleteAllUI(wxUpdateUIEvent &event)
 {
 	event.Enable(m_listTable->GetItemCount()>0);
 }
 
-void SimpleTable::OnDeleteWatch(wxCommandEvent &event)
+void WatchesTable::OnDeleteWatch(wxCommandEvent &event)
 {
 	wxUnusedVar(event);
 	if (m_selectedId != wxNOT_FOUND) {
@@ -145,12 +145,12 @@ void SimpleTable::OnDeleteWatch(wxCommandEvent &event)
 	}
 }
 
-void SimpleTable::OnDeleteWatchUI(wxUpdateUIEvent &event)
+void WatchesTable::OnDeleteWatchUI(wxUpdateUIEvent &event)
 {
 	event.Enable(m_selectedId != wxNOT_FOUND && m_listTable->GetItemCount()>0);
 }
 
-void SimpleTable::AddExpression(const wxString &expr)
+void WatchesTable::AddExpression(const wxString &expr)
 {
 	//make sure that the expression does not exist
 	int count = m_listTable->GetItemCount();
@@ -172,7 +172,7 @@ void SimpleTable::AddExpression(const wxString &expr)
 	m_listTable->SetColumnWidth(1, 600);
 }
 
-void SimpleTable::RefreshValues()
+void WatchesTable::RefreshValues()
 {
 	//ask the debugger to update the table
 	//to trigger the update for the table we issue a simple
@@ -185,7 +185,7 @@ void SimpleTable::RefreshValues()
 	}
 }
 
-void SimpleTable::UpdateExpression(const wxString &expr, const wxString &value)
+void WatchesTable::UpdateExpression(const wxString &expr, const wxString &value)
 {
 	//find the item of this expression
 	long item = FindExpressionItem(expr);
@@ -196,7 +196,7 @@ void SimpleTable::UpdateExpression(const wxString &expr, const wxString &value)
 	SetColumnText(item, 1, value);
 }
 
-void SimpleTable::SetColumnText ( long indx, long column, const wxString &rText )
+void WatchesTable::SetColumnText ( long indx, long column, const wxString &rText )
 {
 	m_listTable->Freeze();
 	wxListItem list_item;
@@ -208,7 +208,7 @@ void SimpleTable::SetColumnText ( long indx, long column, const wxString &rText
 	m_listTable->Thaw();
 }
 
-wxString SimpleTable::GetColumnText(long index, long column)
+wxString WatchesTable::GetColumnText(long index, long column)
 {
 	wxListItem list_item;
 	list_item.SetId ( index );
@@ -218,7 +218,7 @@ wxString SimpleTable::GetColumnText(long index, long column)
 	return list_item.GetText();
 }
 
-long SimpleTable::FindExpressionItem(const wxString &expression)
+long WatchesTable::FindExpressionItem(const wxString &expression)
 {
 	long item = -1;
 	while ( true ) {
@@ -236,7 +236,7 @@ long SimpleTable::FindExpressionItem(const wxString &expression)
 	return wxNOT_FOUND;
 }
 
-wxArrayString SimpleTable::GetExpressions()
+wxArrayString WatchesTable::GetExpressions()
 {
 	long item = wxNOT_FOUND;
 	wxArrayString expressions;
@@ -254,24 +254,19 @@ wxArrayString SimpleTable::GetExpressions()
 	return expressions;
 }
 
-void SimpleTable::DoShowMoreDetails(long item)
-{
-	ManagerST::Get()->DbgQuickWatch(GetColumnText(item, 0));
-}
-
-void SimpleTable::OnMenuExpandExpr(wxCommandEvent &event)
+void WatchesTable::OnMenuExpandExpr(wxCommandEvent &event)
 {
 	wxUnusedVar(event);
 	DoShowMoreDetails(m_selectedId);
 }
 
-void SimpleTable::OnListEditLabelEnd(wxListEvent &event)
+void WatchesTable::OnListEditLabelEnd(wxListEvent &event)
 {
 	wxUnusedVar(event);
 	RefreshValues();
 }
 
-void SimpleTable::OnMenuDerefExpr(wxCommandEvent &event)
+void WatchesTable::OnMenuDerefExpr(wxCommandEvent &event)
 {
 	wxUnusedVar(event);
 	if (m_selectedId != wxNOT_FOUND) {
@@ -282,7 +277,7 @@ void SimpleTable::OnMenuDerefExpr(wxCommandEvent &event)
 	}
 }
 
-void SimpleTable::OnMenuEditExpr(wxCommandEvent &event)
+void WatchesTable::OnMenuEditExpr(wxCommandEvent &event)
 {
 	wxUnusedVar(event);
 	if (m_selectedId != wxNOT_FOUND) {
@@ -295,7 +290,7 @@ void SimpleTable::OnMenuEditExpr(wxCommandEvent &event)
 	}
 }
 
-void SimpleTable::OnMenuCopyExpr(wxCommandEvent& event)
+void WatchesTable::OnMenuCopyExpr(wxCommandEvent& event)
 {
 	wxUnusedVar(event);
 	if (m_selectedId != wxNOT_FOUND) {
@@ -305,7 +300,7 @@ void SimpleTable::OnMenuCopyExpr(wxCommandEvent& event)
 	}
 }
 
-void SimpleTable::OnMenuCopyBoth(wxCommandEvent& event)
+void WatchesTable::OnMenuCopyBoth(wxCommandEvent& event)
 {
 	wxUnusedVar(event);
 	if (m_selectedId != wxNOT_FOUND) {
@@ -316,7 +311,7 @@ void SimpleTable::OnMenuCopyBoth(wxCommandEvent& event)
 	}
 }
 
-void SimpleTable::OnMenuCopyValue(wxCommandEvent& event)
+void WatchesTable::OnMenuCopyValue(wxCommandEvent& event)
 {
 	wxUnusedVar(event);
 	if (m_selectedId != wxNOT_FOUND) {
@@ -326,7 +321,7 @@ void SimpleTable::OnMenuCopyValue(wxCommandEvent& event)
 	}
 }
 
-void SimpleTable::OnDisplayFormat(wxCommandEvent& event)
+void WatchesTable::OnDisplayFormat(wxCommandEvent& event)
 {
 	wxUnusedVar(event);
 
@@ -334,12 +329,12 @@ void SimpleTable::OnDisplayFormat(wxCommandEvent& event)
 	RefreshValues();
 }
 
-wxString SimpleTable::GetDisplayFormat()
+wxString WatchesTable::GetDisplayFormat()
 {
 	return m_choiceDisplayFormat->GetStringSelection();
 }
 
-void SimpleTable::OnNewWatch_Iternal(wxCommandEvent& event)
+void WatchesTable::OnNewWatch_Iternal(wxCommandEvent& event)
 {
 	wxString expr = event.GetString();
 	if( expr.empty() == false ){
@@ -347,3 +342,14 @@ void SimpleTable::OnNewWatch_Iternal(wxCommandEvent& event)
 		RefreshValues();
 	}
 }
+
+void WatchesTable::DoShowMoreDetails(long item)
+{
+	if( item != wxNOT_FOUND ) {
+		wxString value = GetColumnText(item, 0);
+		IDebugger *dbgr = DebuggerMgr::Get().GetActiveDebugger();
+		if ( dbgr && dbgr->IsRunning() && ManagerST::Get()->DbgCanInteract() ) {
+			dbgr->CreateVariableObject( value, DBG_USERR_WATCHTABLE );
+		}
+	}
+}
