@@ -81,7 +81,12 @@ TaskPanel::TaskPanel(wxWindow* parent, wxWindowID id, const wxString &name)
 	mainSizer->Detach(m_sci);
 	vertSizer->Add(m_sci, 1, wxEXPAND | wxALL, 1);
 
+#ifdef __WXMAC__
+	mainSizer->Insert(0, vertSizer, 1, wxEXPAND | wxALL, 1);
+#else
 	mainSizer->Add(vertSizer, 1, wxEXPAND | wxALL, 1);
+#endif
+
 	mainSizer->Layout();
 }
 
@@ -96,7 +101,7 @@ SearchData TaskPanel::DoGetSearchData()
     data.SetRegularExpression(true);
     data.SetMatchCase(false);
     data.SetMatchWholeWord(false);
-    data.SetUseEditorFontConfig(false);
+    data.SetEncoding(wxT("ISO-8859-1"));
     data.SetOwner(this);
 
 	wxString sfind;
