@@ -84,7 +84,7 @@ public:
 
 private:
 	BuildConfigCommon m_commonConfig;
-	
+
 	wxString m_name;
 	BuildCommandList m_preBuildCommands;
 	BuildCommandList m_postBuildCommands;
@@ -101,6 +101,7 @@ private:
 	wxString m_projectType;
 	wxString m_customBuildCmd;
 	wxString m_customCleanCmd;
+	wxString m_customRebuildCmd;
 	bool m_isResCmpNeeded;
 	wxString m_debuggerType;
 	wxString m_customPostBuildRule;
@@ -110,7 +111,7 @@ private:
 	wxString m_toolName;
 	wxString m_makeGenerationCommand;
 	wxString m_singleFileBuildCommand;
-    wxString m_preprocessFileCommand;
+	wxString m_preprocessFileCommand;
 	wxString m_debuggerStartupCmds;
 	wxString m_debuggerPostRemoteConnectCmds;
 	bool m_isDbgRemoteTarget;
@@ -121,6 +122,7 @@ private:
 	wxString m_buildCmpWithGlobalSettings;
 	wxString m_buildLnkWithGlobalSettings;
 	wxString m_buildResWithGlobalSettings;
+	wxString m_precompiledHeader;
 
 public:
 	BuildConfig(wxXmlNode *node);
@@ -193,6 +195,9 @@ public:
 	const wxString &GetCustomCleanCmd()const {
 		return m_customCleanCmd;
 	}
+	const wxString& GetCustomRebuildCmd() const {
+		return m_customRebuildCmd;
+	}
 	void SetIncludePath(const wxArrayString &paths) {
 		m_commonConfig.SetIncludePath(paths);
 	}
@@ -249,6 +254,9 @@ public:
 	void SetCustomCleanCmd(const wxString &cmd) {
 		m_customCleanCmd = cmd;
 	}
+	void SetCustomRebuildCmd(const wxString &cmd) {
+		m_customRebuildCmd = cmd;
+	}
 	void EnableCustomBuild(bool enable) {
 		m_enableCustomBuild = enable;
 	}
@@ -323,13 +331,13 @@ public:
 	const wxString& GetSingleFileBuildCommand() const {
 		return m_singleFileBuildCommand;
 	}
-    
-    void SetPreprocessFileCommand(const wxString &preprocessFileCommand) {
-        this->m_preprocessFileCommand = preprocessFileCommand;
-    }
-    const wxString &GetPreprocessFileCommand() const {
-        return m_preprocessFileCommand;
-    }
+
+	void SetPreprocessFileCommand(const wxString &preprocessFileCommand) {
+		this->m_preprocessFileCommand = preprocessFileCommand;
+	}
+	const wxString &GetPreprocessFileCommand() const {
+		return m_preprocessFileCommand;
+	}
 
 	const wxString &GetProjectType() const {
 		return m_projectType;
@@ -385,31 +393,37 @@ public:
 	const wxString& GetDebuggerPostRemoteConnectCmds() const {
 		return m_debuggerPostRemoteConnectCmds;
 	}
-	
+
 	const wxString& GetBuildCmpWithGlobalSettings() const {
 		return m_buildCmpWithGlobalSettings;
 	}
 	void SetBuildCmpWithGlobalSettings(const wxString &buildType) {
 		m_buildCmpWithGlobalSettings = buildType;
 	}
-	
+
 	const wxString& GetBuildLnkWithGlobalSettings() const {
 		return m_buildLnkWithGlobalSettings;
 	}
 	void SetBuildLnkWithGlobalSettings(const wxString &buildType) {
 		m_buildLnkWithGlobalSettings = buildType;
 	}
-	
+
 	const wxString& GetBuildResWithGlobalSettings() const {
 		return m_buildResWithGlobalSettings;
 	}
 	void SetBuildResWithGlobalSettings(const wxString &buildType) {
 		m_buildResWithGlobalSettings = buildType;
 	}
-	
+
 	const BuildConfigCommon& GetCommonConfiguration() const {
 		return m_commonConfig;
 	}
+	void SetPrecompiledHeader(const wxString& precompiledHeader) {
+		this->m_precompiledHeader = precompiledHeader;
+	}
+	const wxString& GetPrecompiledHeader() const {
+		return m_precompiledHeader;
+	}
 };
 
 typedef SmartPtr<BuildConfig> BuildConfigPtr;
