@@ -78,10 +78,10 @@ static wxString GetMakeDirCmd(BuildConfigPtr bldConf, const wxString &relPath =
 
 	wxString text;
 	if (OS_WINDOWS) {
-		text << wxT("@makedir \"") << relativePath << intermediateDirectory << wxT("\"");
+		text << wxT("@$(MakeDirCommand) \"") << relativePath << intermediateDirectory << wxT("\"");
 	} else {
 		//other OSs
-		text << wxT("@test -d ") << relativePath << intermediateDirectory << wxT(" || mkdir -p ") << relativePath << intermediateDirectory;
+		text << wxT("@test -d ") << relativePath << intermediateDirectory << wxT(" || $(MakeDirCommand) ") << relativePath << intermediateDirectory;
 	}
 	return text;
 }
@@ -159,9 +159,12 @@ bool BuilderGnuMake::Export(const wxString &project, const wxString &confToBuild
 				settingsChanged = true;
 			}
 		}
-		//update the project dependencies a
+		//update the project dependencies
 		bool modified = proj->IsModified();
-		proj->SetDependencies(depsArr, bld_conf_name);
+
+		// Update the dependencies only if needed
+		if(settingsChanged)
+			proj->SetDependencies(depsArr, bld_conf_name);
 
 		//the set settings functions marks the project as 'modified' this causes
 		//an unneeded makefile generation if the settings was not really modified
@@ -182,7 +185,7 @@ bool BuilderGnuMake::Export(const wxString &project, const wxString &confToBuild
 
 	//iterate over the dependencies projects and generate makefile
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(false);
-	buildTool = WorkspaceST::Get()->ExpandVariables(buildTool);
+	buildTool = EnvironmentConfig::Instance()->ExpandVariables(buildTool, true);
 
 	// fix: replace all Windows like slashes to POSIX
 	buildTool.Replace(wxT("\\"), wxT("/"));
@@ -476,28 +479,35 @@ void BuilderGnuMake::GenerateMakefile(ProjectPtr proj, const wxString &confToBui
 	wxString text;
 
 	text << wxT("##") << wxT("\n");
-	text << wxT("## Auto Generated makefile, please do not edit") << wxT("\n");;
+	text << wxT("## Auto Generated makefile by CodeLite IDE") << wxT("\n");
+	text << wxT("## any manual changes will be erased      ") << wxT("\n");
 	text << wxT("##") << wxT("\n");
 
+	// Create the makefile variables
+	CreateConfigsVariables(proj, bldConf, text);
+
+
 	//----------------------------------------------------------
-	//copy environment variables to the makefile
+	// copy environment variables to the makefile
+	// We put them after the 'hard-coeded' ones
+	// so user will be able to override any of the default
+	// variables by defining its own
 	//----------------------------------------------------------
 	EvnVarList vars;
 	EnvironmentConfig::Instance()->ReadObject(wxT("Variables"), &vars);
-	std::map<wxString, wxString> varMap = vars.GetVariables();
-	std::map<wxString, wxString>::const_iterator iter = varMap.begin();
+	EnvMap varMap = vars.GetVariables();
 
-	for (; iter != varMap.end(); iter++) {
-		wxString name = iter->first;
-		wxString value = iter->second;
+	text << wxT("##") << wxT("\n");
+	text << wxT("## User defined environment variables") << wxT("\n");
+	text << wxT("##") << wxT("\n");
+
+	for (size_t i=0; i<varMap.GetCount(); i++) {
+		wxString name, value;
+		varMap.Get(i, name, value);
 		text << name << wxT(":=") << value << wxT("") << wxT("\n");
 	}
 
-	//create a variable for the project name as well
-	text << wxT("ProjectName:=") << proj->GetName() << wxT("\n");
-	text << wxT("\n");
 
-	CreateConfigsVariables(proj, bldConf, text);
 	CreateListMacros(proj, confToBuild, text); // list of srcs and list of objects
 
 	//-----------------------------------------------------------
@@ -523,8 +533,8 @@ void BuilderGnuMake::GenerateMakefile(ProjectPtr proj, const wxString &confToBui
 	// Create a list of targets that should be built according to
 	// projects' file list
 	//-----------------------------------------------------------
-	CreateFileTargets(proj, confToBuild, text); 
-	CreateCleanTargets(proj, confToBuild, text); 	
+	CreateFileTargets(proj, confToBuild, text);
+	CreateCleanTargets(proj, confToBuild, text);
 
     //dump the content to a file
 	wxFFile output;
@@ -589,18 +599,18 @@ void BuilderGnuMake::CreateSrcList(ProjectPtr proj, const wxString &confToBuild,
 void BuilderGnuMake::CreateObjectList(ProjectPtr proj, const wxString &confToBuild, wxString &text)
 {
 	std::vector<wxFileName> files;
-	proj->GetFiles(files);
+	proj->GetFiles(files, true);
 	text << wxT("Objects=");
 
 	BuildConfigPtr bldConf = WorkspaceST::Get()->GetProjBuildConf(proj->GetName(), confToBuild);
 	wxString cmpType = bldConf->GetCompilerType();
-	wxString relPath;
 
 	//get the compiler settings
 	CompilerPtr cmp = BuildSettingsConfigST::Get()->GetCompiler(cmpType);
 
 	int counter = 1;
 	Compiler::CmpFileTypeInfo ft;
+	wxString cwd = ::wxGetCwd();
 
 	for (size_t i=0; i<files.size(); i++) {
 
@@ -613,15 +623,14 @@ void BuilderGnuMake::CreateObjectList(ProjectPtr proj, const wxString &confToBui
 			continue;
 		}
 
-		relPath = files.at(i).GetPath(true, wxPATH_UNIX);
-		relPath.Trim().Trim(false);
+		wxString objPrefix = DoGetTargetPrefix(files.at(i), cwd);
 
 		if (ft.kind == Compiler::CmpFileKindResource) {
 			// resource files are handled differently
-			text << relPath << wxT("$(IntermediateDirectory)/") << files[i].GetFullName() << wxT("$(ObjectSuffix) ");
+			text << wxT("$(IntermediateDirectory)/") << objPrefix << files[i].GetFullName() << wxT("$(ObjectSuffix) ");
 		} else {
 			// Compiler::CmpFileKindSource file
-			text << relPath << wxT("$(IntermediateDirectory)/") << files[i].GetName() << wxT("$(ObjectSuffix) ");
+			text << wxT("$(IntermediateDirectory)/") << objPrefix << files[i].GetName() << wxT("$(ObjectSuffix) ");
 		}
 		if (counter % 10 == 0) {
 			text << wxT("\\\n\t");
@@ -663,6 +672,8 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString &confToBu
 	// Collect all the sub-directories that we generate files for
 	wxArrayString subDirs;
 
+	wxString cwd = proj->GetFileName().GetPath();
+
 	PRINT_TIMESTAMP(wxT("Looping over the file list...\n"));
 	for (size_t i=0; i<abs_files.size(); i++) {
 		// is this file interests the compiler?
@@ -670,16 +681,11 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString &confToBu
 			wxString absFileName;
 			wxFileName fn( abs_files.at(i) );
 
-			wxString filenameOnly = fn.GetName();
-			wxString fullpathOnly = fn.GetFullPath();
-			wxString fullnameOnly = fn.GetFullName();
+			wxString filenameOnly    = fn.GetName();
+			wxString fullpathOnly    = fn.GetFullPath();
+			wxString fullnameOnly    = fn.GetFullName();
 			wxString compilationLine = ft.compilation_line;
 
-			compilationLine.Replace(wxT("$(FileName)"),     filenameOnly);
-			compilationLine.Replace(wxT("$(FileFullName)"), fullnameOnly);
-			compilationLine.Replace(wxT("$(FileFullPath)"), fullpathOnly);
-
-
 			// use UNIX style slashes
 			absFileName = abs_files[i].GetFullPath();
 			absFileName.Replace(wxT("\\"), wxT("/"));
@@ -688,42 +694,47 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString &confToBu
 			relPath = rel_paths.at(i).GetPath(true, wxPATH_UNIX);
 			relPath.Trim().Trim(false);
 
-			if(subDirs.Index(relPath) == wxNOT_FOUND) {
-				subDirs.Add(relPath);
-			}
+			wxString objPrefix = DoGetTargetPrefix(abs_files.at(i), cwd);
 
+			compilationLine.Replace(wxT("$(FileName)"),     filenameOnly);
+			compilationLine.Replace(wxT("$(FileFullName)"), fullnameOnly);
+			compilationLine.Replace(wxT("$(FileFullPath)"), fullpathOnly);
 			compilationLine.Replace(wxT("$(FilePath)"),     relPath);
-			compilationLine.Replace(wxT("\\"), wxT("/"));
+
+			// The object name is handled differently when using resource files
+			if(ft.kind == Compiler::CmpFileKindResource)
+				compilationLine.Replace(wxT("$(ObjectName)"),   objPrefix + fullnameOnly);
+			else
+				compilationLine.Replace(wxT("$(ObjectName)"),   objPrefix + filenameOnly);
+
+			compilationLine.Replace(wxT("$(ObjectName)"),   objPrefix + filenameOnly);
+			compilationLine.Replace(wxT("\\"),              wxT("/"));
 
 			if (ft.kind == Compiler::CmpFileKindSource) {
 				wxString objectName;
 				wxString dependFile;
 				wxString preprocessedFile;
 
-
-				objectName << relPath << wxT("$(IntermediateDirectory)/") << filenameOnly << wxT("$(ObjectSuffix)");
+				objectName << wxT("$(IntermediateDirectory)/") << objPrefix << filenameOnly << wxT("$(ObjectSuffix)");
 				if (generateDependenciesFiles) {
-					dependFile << relPath << wxT("$(IntermediateDirectory)/") << filenameOnly << wxT("$(DependSuffix)");
+					dependFile << wxT("$(IntermediateDirectory)/") << objPrefix << filenameOnly << wxT("$(DependSuffix)");
 				}
 				if (supportPreprocessOnlyFiles) {
-					preprocessedFile << relPath << wxT("$(IntermediateDirectory)/") << filenameOnly << wxT("$(PreprocessSuffix)");
+					preprocessedFile << wxT("$(IntermediateDirectory)/") << objPrefix << filenameOnly << wxT("$(PreprocessSuffix)");
 				}
 
 				// set the file rule
 				text << objectName << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT(" ") << dependFile << wxT("\n");
-				text << wxT("\t") << GetMakeDirCmd(bldConf, relPath) << wxT("\n");
 				text << wxT("\t") << compilationLine << wxT("\n");
 
 				wxString compilerMacro = DoGetCompilerMacro(rel_paths.at(i).GetFullPath(wxPATH_UNIX));
 				if (generateDependenciesFiles) {
 					text << dependFile << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT("\n");
-					text << wxT("\t") << GetMakeDirCmd(bldConf, relPath) << wxT("\n");
 					text << wxT("\t") << wxT("@") << compilerMacro << wxT(" $(CmpOptions) $(IncludePath) -MT") << objectName <<wxT(" -MF") << dependFile << wxT(" -MM \"") << absFileName << wxT("\"\n\n");
 				}
 
 				if (supportPreprocessOnlyFiles) {
 					text << preprocessedFile << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT("\n");
-					text << wxT("\t") << GetMakeDirCmd(bldConf, relPath) << wxT("\n");
 					text << wxT("\t") << wxT("@") << compilerMacro << wxT(" $(CmpOptions) $(IncludePath) $(PreprocessOnlySwitch) $(OutputSwitch) ") << preprocessedFile << wxT(" \"") << absFileName << wxT("\"\n\n");
 				}
 
@@ -731,10 +742,9 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString &confToBu
 				// we construct an object name which also includes the full name of the reousrce file and appends a .o to the name (to be more
 				// precised, $(ObjectSuffix))
 				wxString objectName;
-				objectName << relPath << wxT("$(IntermediateDirectory)/") << fullnameOnly << wxT("$(ObjectSuffix)");
+				objectName << wxT("$(IntermediateDirectory)/") << objPrefix << fullnameOnly << wxT("$(ObjectSuffix)");
 
 				text << objectName << wxT(": ") << rel_paths.at(i).GetFullPath(wxPATH_UNIX) << wxT("\n");
-				text << wxT("\t") << GetMakeDirCmd(bldConf, relPath) << wxT("\n");
 				text << wxT("\t") << compilationLine << wxT("\n");
 			}
 		}
@@ -742,10 +752,9 @@ void BuilderGnuMake::CreateFileTargets(ProjectPtr proj, const wxString &confToBu
 
 	if (generateDependenciesFiles) {
 		text << wxT("\n");
-		for(size_t i=0; i<subDirs.GetCount(); i++) {
-			text << wxT("-include ") << subDirs.Item(i) << wxT("$(IntermediateDirectory)/*$(DependSuffix)\n");
-		}
+		text << wxT("-include ") << wxT("$(IntermediateDirectory)/*$(DependSuffix)\n");
 	}
+
 	PRINT_TIMESTAMP(wxT("Looping over the file list...done\n"));
 	PRINT_TIMESTAMP(wxT("Creating file targets...done\n"));
 }
@@ -761,6 +770,14 @@ void BuilderGnuMake::CreateCleanTargets(ProjectPtr proj, const wxString &confToB
 	CompilerPtr cmp = BuildSettingsConfigST::Get()->GetCompiler(cmpType);
 	std::vector<wxFileName> abs_files, rel_paths;
 
+	// Can we use asterisk in the clean command?
+	long asterisk(0);
+	EditorConfigST::Get()->GetLongValue(wxT("CleanTragetWithAsterisk"), asterisk);
+
+	wxString imd = bldConf->GetIntermediateDirectory();
+	imd.Trim().Trim(false);
+	bool useAsterisk = ((imd.IsEmpty() == false) && asterisk);
+
 	// support for full path
 	PRINT_TIMESTAMP(wxT("Loading file list for clean...\n"));
 	proj->GetFiles(rel_paths, abs_files);
@@ -772,30 +789,38 @@ void BuilderGnuMake::CreateCleanTargets(ProjectPtr proj, const wxString &confToB
 	text << wxT("##\n");
 	text << wxT("clean:\n");
 
+	wxString cwd = proj->GetFileName().GetPath();
 	if (OS_WINDOWS) {
-		//windows clean command
-		for (size_t i=0; i<abs_files.size(); i++) {
 
-			Compiler::CmpFileTypeInfo ft;
-			if (cmp->GetCmpFileType(abs_files[i].GetExt(), ft)) {
-				wxString relPath;
-				relPath = rel_paths.at(i).GetPath(true, wxPATH_UNIX);
-				relPath.Trim().Trim(false);
+		// Windows clean command
+		if( !useAsterisk ) {
+			for (size_t i=0; i<abs_files.size(); i++) {
 
-				if (ft.kind == Compiler::CmpFileKindSource) {
+				Compiler::CmpFileTypeInfo ft;
+				if (cmp->GetCmpFileType(abs_files[i].GetExt(), ft)) {
+					wxString objPrefix = DoGetTargetPrefix(abs_files.at(i), cwd);
 
-					wxString objectName = abs_files[i].GetName() << wxT("$(ObjectSuffix)");
-					wxString dependFile = abs_files[i].GetName() << wxT("$(DependSuffix)");
-					wxString preprocessFile = abs_files[i].GetName() << wxT("$(PreprocessSuffix)");
-					text << wxT("\t") << wxT("$(RM) ") << relPath << wxT("$(IntermediateDirectory)/") << objectName << wxT("\n");
-					text << wxT("\t") << wxT("$(RM) ") << relPath << wxT("$(IntermediateDirectory)/") << dependFile << wxT("\n");
-					text << wxT("\t") << wxT("$(RM) ") << relPath << wxT("$(IntermediateDirectory)/") << preprocessFile << wxT("\n");
+					if (ft.kind == Compiler::CmpFileKindSource) {
 
-				} else if (ft.kind == Compiler::CmpFileKindResource && bldConf->IsResCompilerRequired()) {
-					wxString ofile = abs_files[i].GetFullName() << wxT("$(ObjectSuffix)");
-					text << wxT("\t") << wxT("$(RM) ") << relPath << wxT("$(IntermediateDirectory)/") << ofile << wxT("\n");
+						wxString objectName, dependFile, preprocessFile;
+						objectName     << objPrefix << abs_files[i].GetName() << wxT("$(ObjectSuffix)");
+						dependFile     << objPrefix << abs_files[i].GetName() << wxT("$(DependSuffix)");
+						preprocessFile << objPrefix << abs_files[i].GetName() << wxT("$(PreprocessSuffix)");
+
+						text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << objectName     << wxT("\n");
+						text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << dependFile     << wxT("\n");
+						text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << preprocessFile << wxT("\n");
+
+					} else if (ft.kind == Compiler::CmpFileKindResource && bldConf->IsResCompilerRequired()) {
+						wxString ofile = abs_files[i].GetFullName() + wxT("$(ObjectSuffix)");
+						text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << ofile << wxT("\n");
+
+					}
 				}
 			}
+		} else {
+			// We can use asterisk (intermediat directory is not empty)
+			text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/*.*") << wxT("\n");
 		}
 
 		//delete the output file as well
@@ -819,22 +844,32 @@ void BuilderGnuMake::CreateCleanTargets(ProjectPtr proj, const wxString &confToB
 		}
 	} else {
 		//on linux we dont really need resource compiler...
-		for (size_t i=0; i<abs_files.size(); i++) {
-			Compiler::CmpFileTypeInfo ft;
-			if (cmp->GetCmpFileType(abs_files[i].GetExt(), ft) && ft.kind == Compiler::CmpFileKindSource) {
+		if(!useAsterisk) {
+			for (size_t i=0; i<abs_files.size(); i++) {
 
-				wxString relPath;
-				relPath = rel_paths.at(i).GetPath(true, wxPATH_UNIX);
-				relPath.Trim().Trim(false);
+				wxString objPrefix = DoGetTargetPrefix( abs_files.at(i), cwd );
 
-				wxString objectName = abs_files[i].GetName() << wxT("$(ObjectSuffix)");
-				wxString dependFile = abs_files[i].GetName() << wxT("$(DependSuffix)");
-				wxString preprocessFile = abs_files[i].GetName() << wxT("$(PreprocessSuffix)");
+				Compiler::CmpFileTypeInfo ft;
+				if (cmp->GetCmpFileType(abs_files[i].GetExt(), ft) && ft.kind == Compiler::CmpFileKindSource) {
 
-				text << wxT("\t") << wxT("$(RM) ") << relPath << wxT("$(IntermediateDirectory)/") << objectName << wxT("\n");
-				text << wxT("\t") << wxT("$(RM) ") << relPath << wxT("$(IntermediateDirectory)/") << dependFile << wxT("\n");
-				text << wxT("\t") << wxT("$(RM) ") << relPath << wxT("$(IntermediateDirectory)/") << preprocessFile << wxT("\n");
+					wxString relPath;
+					relPath = rel_paths.at(i).GetPath(true, wxPATH_UNIX);
+					relPath.Trim().Trim(false);
+
+					wxString objectName, dependFile, preprocessFile;
+
+					objectName     << objPrefix << abs_files[i].GetName() << wxT("$(ObjectSuffix)");
+					dependFile     << objPrefix << abs_files[i].GetName() << wxT("$(DependSuffix)");
+					preprocessFile << objPrefix << abs_files[i].GetName() << wxT("$(PreprocessSuffix)");
+
+					text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << objectName     << wxT("\n");
+					text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << dependFile     << wxT("\n");
+					text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/") << preprocessFile << wxT("\n");
+				}
 			}
+
+		} else {
+			text << wxT("\t") << wxT("$(RM) ") << wxT("$(IntermediateDirectory)/*.*") << wxT("\n");
 		}
 
 		//delete the output file as well
@@ -859,7 +894,7 @@ void BuilderGnuMake::CreateListMacros(ProjectPtr proj, const wxString &confToBui
 	// create a list of Sources
 	// CreateSrcList(proj, confToBuild, text);  // Not used/needed for multi-step build
 	// create a list of objects
-	CreateObjectList(proj, confToBuild, text); 
+	CreateObjectList(proj, confToBuild, text);
 }
 
 void BuilderGnuMake::CreateLinkTargets(const wxString &type, BuildConfigPtr bldConf, wxString &text, wxString &targetName)
@@ -884,11 +919,7 @@ void BuilderGnuMake::CreateLinkTargets(const wxString &type, BuildConfigPtr bldC
 
 void BuilderGnuMake::CreateTargets(const wxString &type, BuildConfigPtr bldConf, wxString &text)
 {
-	if (OS_WINDOWS) {
-		text << wxT("\t") << wxT("@makedir $(@D)\n");
-	} else {
-		text << wxT("\t") << wxT("@mkdir -p $(@D)\n");
-	}
+	text << wxT("\t@$(MakeDirCommand) $(@D)\n");
 
 	if (type == Project::STATIC_LIBRARY) {
 		//create a static library
@@ -999,6 +1030,7 @@ void BuilderGnuMake::CreateConfigsVariables(ProjectPtr proj, BuildConfigPtr bldC
 	text << wxT("## ") << name << wxT("\n");
 
 	// Expand the build macros into the generated makefile
+	text << wxT("ProjectName            :=") << proj->GetName() << wxT("\n");
 	text << wxT("ConfigurationName      :=") << name << wxT("\n");
 	text << wxT("IntermediateDirectory  :=") << bldConf->GetIntermediateDirectory() << wxT("\n");
 	text << wxT("OutDir                 := $(IntermediateDirectory)\n");
@@ -1031,6 +1063,12 @@ void BuilderGnuMake::CreateConfigsVariables(ProjectPtr proj, BuildConfigPtr bldC
 	text << wxT("ArchiveOutputSwitch    :=") << cmp->GetSwitch(wxT("ArchiveOutput")) << wxT("\n");
 	text << wxT("PreprocessOnlySwitch   :=") << cmp->GetSwitch(wxT("PreprocessOnly")) << wxT("\n");
 
+	if (OS_WINDOWS) {
+		text << wxT("MakeDirCommand         :=") << wxT("makedir") << wxT("\n");
+	} else {
+		text << wxT("MakeDirCommand         :=") << wxT("mkdir -p") << wxT("\n");
+	}
+
 	wxString buildOpts = bldConf->GetCompileOptions();
 	buildOpts.Replace(wxT(";"), wxT(" "));
 
@@ -1158,7 +1196,7 @@ wxString BuilderGnuMake::GetBuildCommand(const wxString &project, const wxString
 
 	BuildMatrixPtr matrix = WorkspaceST::Get()->GetBuildMatrix();
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(true);
-	buildTool = WorkspaceST::Get()->ExpandVariables(buildTool);
+	buildTool = EnvironmentConfig::Instance()->ExpandVariables(buildTool, true);
 
 	// fix: replace all Windows like slashes to POSIX
 	buildTool.Replace(wxT("\\"), wxT("/"));
@@ -1180,7 +1218,7 @@ wxString BuilderGnuMake::GetCleanCommand(const wxString &project, const wxString
 	Export(project, confToBuild, false, false, errMsg);
 
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(true);
-	buildTool = WorkspaceST::Get()->ExpandVariables(buildTool);
+	buildTool = EnvironmentConfig::Instance()->ExpandVariables(buildTool, true);
 
 	// fix: replace all Windows like slashes to POSIX
 	buildTool.Replace(wxT("\\"), wxT("/"));
@@ -1242,18 +1280,22 @@ wxString BuilderGnuMake::GetSingleFileCmd(const wxString &project, const wxStrin
 
 	cmpType = bldConf->GetCompilerType();
 	CompilerPtr cmp = BuildSettingsConfigST::Get()->GetCompiler(cmpType);
-	fn.MakeRelativeTo(proj->GetFileName().GetPath());
+	//fn.MakeRelativeTo(proj->GetFileName().GetPath());
 
 	wxString relPath = fn.GetPath(true, wxPATH_UNIX);
-	target << relPath << bldConf->GetIntermediateDirectory() << wxT("/") << fn.GetName() << cmp->GetObjectSuffix();
+	wxString objNamePrefix = DoGetTargetPrefix(fn, proj->GetFileName().GetPath());
+	target << bldConf->GetIntermediateDirectory() << wxT("/") << objNamePrefix << fn.GetName() << cmp->GetObjectSuffix();
 
 	cmd = GetProjectMakeCommand(proj, confToBuild, target, false, false);
-	return EnvironmentConfig::Instance()->ExpandVariables(cmd);
+	return EnvironmentConfig::Instance()->ExpandVariables(cmd, true);
 }
 
 wxString BuilderGnuMake::GetPreprocessFileCmd(const wxString &project, const wxString &confToBuild, const wxString &fileName, wxString &errMsg)
 {
-	// TODO: factor out common code with GetSingleFileCmd()
+	ProjectPtr     proj    = WorkspaceST::Get()->FindProjectByName(project, errMsg);
+	if (!proj) {
+		return wxEmptyString;
+	}
 
 	wxString cmd;
 	BuildConfigPtr bldConf = WorkspaceST::Get()->GetProjBuildConf(project, confToBuild);
@@ -1272,17 +1314,18 @@ wxString BuilderGnuMake::GetPreprocessFileCmd(const wxString &project, const wxS
 	buildTool.Replace(wxT("\\"), wxT("/"));
 
 	//create the target
-	wxString tareget;
+	wxString target;
 	wxString objSuffix;
 	wxFileName fn(fileName);
 
 	wxString cmpType = bldConf->GetCompilerType();
 	CompilerPtr cmp = BuildSettingsConfigST::Get()->GetCompiler(cmpType);
 
-	tareget << bldConf->GetIntermediateDirectory() << wxT("/") << fn.GetName() << cmp->GetPreprocessSuffix();
-	cmd << buildTool << wxT(" \"") << project << wxT(".mk\" ") << tareget;
+	wxString objNamePrefix = DoGetTargetPrefix(fn, proj->GetFileName().GetPath());
+	target << bldConf->GetIntermediateDirectory() << wxT("/") << objNamePrefix << fn.GetName() << cmp->GetPreprocessSuffix();
 
-	return EnvironmentConfig::Instance()->ExpandVariables(cmd);
+	cmd = GetProjectMakeCommand(proj, confToBuild, target, false, false);
+	return EnvironmentConfig::Instance()->ExpandVariables(cmd, true);
 }
 
 wxString BuilderGnuMake::GetCdCmd(const wxFileName &path1, const wxFileName &path2)
@@ -1357,7 +1400,7 @@ wxString BuilderGnuMake::GetProjectMakeCommand(const wxFileName& wspfile, const
 	wxString basicMakeCommand;
 
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(false);
-	buildTool = WorkspaceST::Get()->ExpandVariables(buildTool);
+	buildTool = EnvironmentConfig::Instance()->ExpandVariables(buildTool, true);
 	basicMakeCommand << buildTool << wxT(" \"") << proj->GetName() << wxT(".mk\"");
 
 	makeCommand << wxT("\t") << GetCdCmd(wspfile, projectPath);
@@ -1395,7 +1438,7 @@ wxString BuilderGnuMake::GetProjectMakeCommand(ProjectPtr proj, const wxString&
 	wxString basicMakeCommand;
 
 	wxString buildTool = BuildManagerST::Get()->GetSelectedBuilder()->GetBuildToolCommand(true);
-	buildTool = WorkspaceST::Get()->ExpandVariables(buildTool);
+	buildTool = EnvironmentConfig::Instance()->ExpandVariables(buildTool, true);
 	basicMakeCommand << buildTool << wxT(" \"") << proj->GetName() << wxT(".mk\" ");
 
 	if( addCleanTarget ) {
@@ -1498,3 +1541,33 @@ wxString BuilderGnuMake::DoGetCompilerMacro(const wxString& filename)
 	}
 	return compilerMacro;
 }
+
+wxString BuilderGnuMake::DoGetTargetPrefix(const wxFileName& filename, const wxString &cwd)
+{
+	size_t        count = filename.GetDirCount();
+	wxArrayString dirs  = filename.GetDirs();
+	wxString      lastDir;
+
+	if(cwd == filename.GetPath()) {
+		return wxEmptyString;
+	}
+
+	if(count) {
+		lastDir = dirs.Item(count-1);
+
+		// Handle special directory paths
+		if(lastDir == wxT("..")) {
+			lastDir = wxT("up");
+
+		} else if(lastDir == wxT(".")) {
+			lastDir = wxT("cur");
+		}
+
+		if(lastDir.IsEmpty() == false) {
+			lastDir << wxT("_");
+
+		}
+	}
+
+	return lastDir;
+}
