@@ -52,8 +52,11 @@ extern "C" EXPORT int GetPluginInterfaceVersion()
 }
 
 Subversion2::Subversion2(IManager *manager)
-		: IPlugin          (manager)
-		, m_explorerSepItem(NULL)
+		: IPlugin           (manager)
+		, m_explorerSepItem (NULL)
+		, m_simpleCommand   (this)
+		, m_diffCommand     (this)
+		, m_blameCommand    (this)
 		, m_svnClientVersion(0.0)
 {
 	m_longName = wxT("Subversion plugin for codelite2.0 based on the svn command line tool");
@@ -757,3 +760,33 @@ bool Subversion2::IsPathUnderSvn(const wxString& path)
 
 	return false;
 }
+
+void Subversion2::OnSwitchURL(wxCommandEvent& event)
+{
+	SvnInfo svnInfo;
+	wxString path = DoGetFileExplorerItemPath();
+	DoGetSvnInfoSync(svnInfo, path);
+	DoSwitchURL(DoGetFileExplorerItemPath(), svnInfo.m_sourceUrl, event);
+}
+
+void Subversion2::DoSwitchURL(const wxString& workingDirectory, const wxString &sourceUrl, wxCommandEvent& event)
+{
+	SvnInfo svnInfo;
+	DoGetSvnInfoSync(svnInfo, workingDirectory);
+
+	wxString loginString;
+	if(LoginIfNeeded(event, workingDirectory, loginString) == false) {
+		return;
+	}
+	bool nonInteractive = GetNonInteractiveMode(event);
+
+	wxString targetUrl = wxGetTextFromUser(wxT("Enter new URL:"), wxT("Svn Switch..."), sourceUrl);
+	if(targetUrl.IsEmpty()) {
+		return;
+	}
+
+	wxString command;
+
+	command << GetSvnExeName(nonInteractive) << wxT(" switch ") << targetUrl << loginString;
+	GetConsole()->Execute(command, workingDirectory, new SvnDefaultCommandHandler(this, wxNOT_FOUND, NULL));
+}
