@@ -1,4 +1,5 @@
 #include <wx/app.h>
+#include "diff_dialog.h"
 #include "svn_checkout_dialog.h"
 #include "subversion2_ui.h"
 #include <wx/settings.h>
@@ -48,12 +49,15 @@ BEGIN_EVENT_TABLE(SubversionView, SubversionPageBase)
 	EVT_MENU(XRCID("svn_ignore_file_pattern"),SubversionView::OnIgnoreFilePattern)
 	EVT_MENU(XRCID("svn_blame"),              SubversionView::OnBlame)
 	EVT_MENU(XRCID("svn_checkout"),           SubversionView::OnCheckout)
-
+	EVT_MENU(XRCID("svn_open_file"),          SubversionView::OnOpenFile)
+	EVT_MENU(XRCID("svn_switch"),             SubversionView::OnSwitch)
 END_EVENT_TABLE()
 
 SubversionView::SubversionView( wxWindow* parent, Subversion2 *plugin )
-		: SubversionPageBase( parent )
-		, m_plugin          ( plugin )
+	: SubversionPageBase( parent )
+	, m_plugin          ( plugin )
+	, m_simpleCommand   ( plugin )
+	, m_diffCommand     ( plugin )
 {
 	CreatGUIControls();
 	m_plugin->GetManager()->GetTheApp()->Connect(wxEVT_WORKSPACE_LOADED,      wxCommandEventHandler(SubversionView::OnWorkspaceLoaded),     NULL, this);
@@ -356,7 +360,7 @@ SvnTreeData::SvnNodeType SubversionView::DoGetSelectionType(const wxArrayTreeIte
 		}
 
 		if (type == SvnTreeData::SvnNodeTypeInvalid &&
-		        (data->GetType() == SvnTreeData::SvnNodeTypeFile || data->GetType() == SvnTreeData::SvnNodeTypeRoot)) {
+		    (data->GetType() == SvnTreeData::SvnNodeTypeFile || data->GetType() == SvnTreeData::SvnNodeTypeRoot)) {
 			type = data->GetType();
 			m_selectionInfo.m_selectionType = type;
 			m_selectionInfo.m_paths.Add(data->GetFilepath());
@@ -388,6 +392,8 @@ void SubversionView::CreateSecondRootMenu(wxMenu* menu)
 
 void SubversionView::CreateFileMenu(wxMenu* menu)
 {
+	menu->Append(XRCID("svn_open_file"),  wxT("Open File..."));
+	menu->AppendSeparator();
 	menu->Append(XRCID("svn_commit"),  wxT("Commit"));
 	menu->Append(XRCID("svn_update"),  wxT("Update"));
 	menu->AppendSeparator();
@@ -424,6 +430,9 @@ void SubversionView::CreateRootMenu(wxMenu* menu)
 	menu->Append(XRCID("svn_branch"),        wxT("Create Branch"));
 	menu->AppendSeparator();
 
+	menu->Append(XRCID("svn_switch"),   wxT("Switch URL..."));
+	menu->AppendSeparator();
+
 	menu->Append(XRCID("svn_diff"),          wxT("Create Diff..."));
 	menu->Append(XRCID("svn_patch"),         wxT("Apply Patch..."));
 	menu->Append(XRCID("svn_patch_dry_run"), wxT("Apply Patch - Dry Run..."));
@@ -445,10 +454,10 @@ void SubversionView::DoGetPaths(const wxTreeItemId& parent, wxArrayString& paths
 			}
 
 			if (( data->GetType() == SvnTreeData::SvnNodeTypeAddedRoot    ||
-			        data->GetType() == SvnTreeData::SvnNodeTypeModifiedRoot ||
-			        data->GetType() == SvnTreeData::SvnNodeTypeDeletedRoot) &&
+			      data->GetType() == SvnTreeData::SvnNodeTypeModifiedRoot ||
+			      data->GetType() == SvnTreeData::SvnNodeTypeDeletedRoot) &&
 
-			        m_treeCtrl->ItemHasChildren(item)) {
+			    m_treeCtrl->ItemHasChildren(item)) {
 
 				DoGetPaths(item, paths);
 			}
@@ -573,15 +582,15 @@ void SubversionView::OnBranch(wxCommandEvent& event)
 		// Prepare the 'copy' command
 		bool nonInteractive = m_plugin->GetNonInteractiveMode(event);
 		command
-		<< m_plugin->GetSvnExeName(nonInteractive)
-		<< loginString
-		<< wxT(" copy ")
-		<< dlg.GetSourceURL()
-		<< wxT(" ")
-		<< dlg.GetTargetURL()
-		<< wxT(" -m \"")
-		<< dlg.GetMessage()
-		<< wxT("\"");
+		        << m_plugin->GetSvnExeName(nonInteractive)
+		        << loginString
+		        << wxT(" copy ")
+		        << dlg.GetSourceURL()
+		        << wxT(" ")
+		        << dlg.GetTargetURL()
+		        << wxT(" -m \"")
+		        << dlg.GetMessage()
+		        << wxT("\"");
 
 		m_plugin->GetConsole()->Execute(command, m_textCtrlRootDir->GetValue(), new SvnDefaultCommandHandler(m_plugin, event.GetId(), this));
 	}
@@ -614,15 +623,15 @@ void SubversionView::OnTag(wxCommandEvent& event)
 		bool nonInteractive = m_plugin->GetNonInteractiveMode(event);
 		command.Clear();
 		command
-		<< m_plugin->GetSvnExeName(nonInteractive)
-		<< loginString
-		<< wxT(" copy ")
-		<< dlg.GetSourceURL()
-		<< wxT(" ")
-		<< dlg.GetTargetURL()
-		<< wxT(" -m \"")
-		<< dlg.GetMessage()
-		<< wxT("\"");
+		        << m_plugin->GetSvnExeName(nonInteractive)
+		        << loginString
+		        << wxT(" copy ")
+		        << dlg.GetSourceURL()
+		        << wxT(" ")
+		        << dlg.GetTargetURL()
+		        << wxT(" -m \"")
+		        << dlg.GetMessage()
+		        << wxT("\"");
 
 		m_plugin->GetConsole()->Execute(command, m_textCtrlRootDir->GetValue(), new SvnDefaultCommandHandler(m_plugin, event.GetId(), this));
 	}
@@ -674,20 +683,23 @@ void SubversionView::OnDiff(wxCommandEvent& event)
 
 	bool nonInteractive = m_plugin->GetNonInteractiveMode(event);
 
-	wxString diffAgainst(wxT("BASE"));
-	diffAgainst = wxGetTextFromUser(wxT("Insert base revision to diff against:"), wxT("Diff against"), wxT("BASE"), m_plugin->GetManager()->GetTheApp()->GetTopWindow());
-	if (diffAgainst.empty()) {
-		// user clicked 'Cancel'
-		return;
-	}
+	DiffDialog dlg(this, m_plugin->GetManager());
+	if(dlg.ShowModal() == wxID_OK) {
+		wxString from = dlg.GetFromRevision();
+		wxString to   = dlg.GetToRevision();
 
-	// Simple diff
-	wxString command;
-	command << m_plugin->GetSvnExeName(nonInteractive) << loginString << wxT(" diff -r") << diffAgainst << wxT(" ");
-	for (size_t i=0; i<m_selectionInfo.m_paths.GetCount(); i++) {
-		command << wxT("\"") << m_selectionInfo.m_paths.Item(i) << wxT("\" ");
+		if(to.IsEmpty() == false) {
+			to.Prepend(wxT(":"));
+		}
+
+		// Simple diff
+		wxString command;
+		command << m_plugin->GetSvnExeName(nonInteractive) << loginString << wxT(" diff -r") << from << to << wxT(" ");
+		for (size_t i=0; i<m_selectionInfo.m_paths.GetCount(); i++) {
+			command << wxT("\"") << m_selectionInfo.m_paths.Item(i) << wxT("\" ");
+		}
+		m_plugin->GetConsole()->Execute(command, m_textCtrlRootDir->GetValue(), new SvnDiffHandler(m_plugin, event.GetId(), this), false);
 	}
-	m_plugin->GetConsole()->Execute(command, m_textCtrlRootDir->GetValue(), new SvnDiffHandler(m_plugin, event.GetId(), this), false);
 }
 
 void SubversionView::OnPatch(wxCommandEvent& event)
@@ -736,7 +748,7 @@ void SubversionView::OnFileAdded(wxCommandEvent& event)
 			bool     addToSvn(false);
 			wxString command;
 			command << m_plugin->GetSvnExeName() << wxT(" add ");
-			for(size_t i=0; i<files->GetCount(); i++){
+			for(size_t i=0; i<files->GetCount(); i++) {
 
 				if(m_plugin->IsPathUnderSvn(files->Item(i))) {
 					command << wxT("\"") << files->Item(i) << wxT("\" ");
@@ -762,7 +774,7 @@ void SubversionView::OnFileRenamed(wxCommandEvent& event)
 		wxString oldName = files->Item(0);
 		wxString newName = files->Item(1);
 
-		if(m_plugin->IsPathUnderSvn(oldName) == false){
+		if(m_plugin->IsPathUnderSvn(oldName) == false) {
 			event.Skip();
 			return;
 		}
@@ -804,16 +816,24 @@ void SubversionView::OnItemActivated(wxTreeEvent& event)
 
 		SvnTreeData *data = (SvnTreeData *)m_treeCtrl->GetItemData(item);
 		if (data && data->GetType() == SvnTreeData::SvnNodeTypeFile) {
-			paths.Add(m_textCtrlRootDir->GetValue() + wxFileName::GetPathSeparator() + data->GetFilepath());
+			paths.Add(/*m_textCtrlRootDir->GetValue() + wxFileName::GetPathSeparator() + */data->GetFilepath());
 		}
 	}
 
-	for(size_t i=0; i<paths.GetCount(); i++) {
-
-		if(wxFileName(paths.Item(i)).IsDir() == false)
-			m_plugin->GetManager()->OpenFile(paths.Item(i));
-
+	wxString loginString;
+	if(m_plugin->LoginIfNeeded(event, m_textCtrlRootDir->GetValue(), loginString) == false) {
+		return;
 	}
+	bool nonInteractive = m_plugin->GetNonInteractiveMode(event);
+	wxString diffAgainst(wxT("BASE"));
+
+	// Simple diff
+	wxString command;
+	command << m_plugin->GetSvnExeName(nonInteractive) << loginString << wxT(" diff -r") << diffAgainst << wxT(" ");
+	for (size_t i=0; i<paths.GetCount(); i++) {
+		command << wxT("\"") << paths.Item(i) << wxT("\" ");
+	}
+	m_plugin->GetConsole()->Execute(command, m_textCtrlRootDir->GetValue(), new SvnDiffHandler(m_plugin, event.GetId(), this), false);
 }
 
 void SubversionView::OnStopUI(wxUpdateUIEvent& event)
@@ -932,3 +952,37 @@ void SubversionView::DisconnectEvents()
 	m_plugin->GetManager()->GetTheApp()->Disconnect(wxEVT_FILE_RENAMED,     wxCommandEventHandler(SubversionView::OnFileRenamed),              NULL, this);
 	m_plugin->GetManager()->GetTheApp()->Disconnect(wxEVT_ACTIVE_EDITOR_CHANGED, wxCommandEventHandler(SubversionView::OnActiveEditorChanged), NULL, this);
 }
+
+void SubversionView::OnOpenFile(wxCommandEvent& event)
+{
+	wxUnusedVar(event);
+
+	wxArrayTreeItemIds items;
+	wxArrayString      paths;
+	size_t count = m_treeCtrl->GetSelections(items);
+	for(size_t i=0; i<count; i++) {
+		wxTreeItemId item = items.Item(i);
+
+		if(item.IsOk() == false)
+			continue;
+
+		SvnTreeData *data = (SvnTreeData *)m_treeCtrl->GetItemData(item);
+		if (data && data->GetType() == SvnTreeData::SvnNodeTypeFile) {
+			paths.Add(m_textCtrlRootDir->GetValue() + wxFileName::GetPathSeparator() + data->GetFilepath());
+		}
+	}
+
+	for(size_t i=0; i<paths.GetCount(); i++) {
+
+		if(wxFileName(paths.Item(i)).IsDir() == false)
+			m_plugin->GetManager()->OpenFile(paths.Item(i));
+
+	}
+}
+
+void SubversionView::OnSwitch(wxCommandEvent& event)
+{
+	SvnInfo svnInfo;
+	m_plugin->DoGetSvnInfoSync(svnInfo, m_textCtrlRootDir->GetValue());
+	m_plugin->DoSwitchURL(m_textCtrlRootDir->GetValue(), svnInfo.m_sourceUrl, event);
+}
