@@ -124,6 +124,11 @@ void SvnConsole::OnProcessEnd(wxCommandEvent& event)
 	ProcessEventData *ped = (ProcessEventData *)event.GetClientData();
 	delete ped;
 
+	if ( m_process ) {
+		delete m_process;
+		m_process = NULL;
+	}
+
 	if (m_handler) {
 
 		if (m_handler->TestLoginRequired(m_output)) {
@@ -151,11 +156,6 @@ void SvnConsole::OnProcessEnd(wxCommandEvent& event)
 		m_handler = NULL;
 	}
 
-	if ( m_process ) {
-		delete m_process;
-		m_process = NULL;
-	}
-
 	m_workingDirectory.Clear();
 	m_url.Clear();
 }
@@ -259,7 +259,7 @@ bool SvnConsole::DoExecute(const wxString& cmd, SvnCommandHandler* handler, cons
 	m_printProcessOutput = printProcessOutput;
 	if (m_process) {
 		// another process is already running...
-		//AppendText(svnANOTHER_PROCESS_RUNNING);
+		AppendText(svnANOTHER_PROCESS_RUNNING);
 		if (handler)
 			delete handler;
 		return false;
@@ -279,7 +279,9 @@ bool SvnConsole::DoExecute(const wxString& cmd, SvnCommandHandler* handler, cons
 	// Apply the environment variables before executing the command
 	StringMap om;
 	om[wxT("LC_ALL")] = wxT("C");
-	EnvSetter env(m_plugin->GetManager()->GetEnv(), &om);
+
+	bool useOverrideMap = m_plugin->GetSettings().GetFlags() & SvnUsePosixLocale;
+	EnvSetter env(m_plugin->GetManager()->GetEnv(), useOverrideMap ? &om : NULL);
 
 	m_process = CreateAsyncProcess(this, cmdShell, workingDirectory);
 	if (!m_process) {
