@@ -40,6 +40,7 @@
 #include "exelocator.h"
 #include "cscopetab.h"
 #include "cscopedbbuilderthread.h"
+#include <wx/imaglist.h>
 
 static Cscope* thePlugin = NULL;
 
@@ -78,7 +79,7 @@ Cscope::Cscope(IManager *manager)
 	m_topWindow = m_mgr->GetTheApp();
 
 	m_cscopeWin = new CscopeTab(m_mgr->GetOutputPaneNotebook(), m_mgr);
-	m_mgr->GetOutputPaneNotebook()->AddPage(m_cscopeWin, CSCOPE_NAME, CSCOPE_NAME, wxXmlResource::Get()->LoadBitmap(wxT("cscope")), false);
+	m_mgr->GetOutputPaneNotebook()->AddPage(m_cscopeWin, CSCOPE_NAME, false, wxXmlResource::Get()->LoadBitmap(wxT("cscope")));
 
 	Connect(wxEVT_CSCOPE_THREAD_DONE, wxCommandEventHandler(Cscope::OnCScopeThreadEnded), NULL, this);
 	Connect(wxEVT_CSCOPE_THREAD_UPDATE_STATUS, wxCommandEventHandler(Cscope::OnCScopeThreadUpdateStatus), NULL, this);
@@ -91,14 +92,14 @@ Cscope::~Cscope()
 {
 }
 
-wxToolBar *Cscope::CreateToolBar(wxWindow *parent)
+clToolBar *Cscope::CreateToolBar(wxWindow *parent)
 {
 	//support both toolbars icon size
 	int size = m_mgr->GetToolbarIconSize();
 
-	wxToolBar *tb = NULL;
+	clToolBar *tb = NULL;
 	if (m_mgr->AllowToolbar()) {
-		tb = new wxToolBar(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTB_FLAT | wxTB_NODIVIDER);
+		tb = new clToolBar(parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, clTB_DEFAULT_STYLE);
 		tb->SetToolBitmapSize(wxSize(size, size));
 
 		// Sample code that adds single button to the toolbar
@@ -188,10 +189,16 @@ void Cscope::UnHookPopupMenu(wxMenu *menu, MenuType type)
 
 void Cscope::UnPlug()
 {
+	m_topWindow->Disconnect( XRCID("cscope_functions_called_by_this_function"), wxEVT_UPDATE_UI, wxUpdateUIEventHandler(Cscope::OnCscopeUI),        NULL, (wxEvtHandler*)this);
+	m_topWindow->Disconnect( XRCID("cscope_create_db"),                         wxEVT_UPDATE_UI, wxUpdateUIEventHandler(Cscope::OnWorkspaceOpenUI), NULL, (wxEvtHandler*)this);
+	m_topWindow->Disconnect( XRCID("cscope_functions_calling_this_function"),   wxEVT_UPDATE_UI, wxUpdateUIEventHandler(Cscope::OnCscopeUI),        NULL, (wxEvtHandler*)this);
+	m_topWindow->Disconnect( XRCID("cscope_find_global_definition"),            wxEVT_UPDATE_UI, wxUpdateUIEventHandler(Cscope::OnCscopeUI),        NULL, (wxEvtHandler*)this);
+	m_topWindow->Disconnect( XRCID("cscope_find_symbol"),                       wxEVT_UPDATE_UI, wxUpdateUIEventHandler(Cscope::OnCscopeUI),        NULL, (wxEvtHandler*)this);
+
 	// before this plugin is un-plugged we must remove the tab we added
 	for (size_t i=0; i<m_mgr->GetOutputPaneNotebook()->GetPageCount(); i++) {
 		if (m_cscopeWin == m_mgr->GetOutputPaneNotebook()->GetPage(i)) {
-			m_mgr->GetOutputPaneNotebook()->RemovePage(i, false);
+			m_mgr->GetOutputPaneNotebook()->RemovePage(i);
 			m_cscopeWin->Destroy();
 			break;
 		}
@@ -314,7 +321,7 @@ void Cscope::DoCscopeCommand(const wxString &command, const wxString &findWhat,
 	wxArrayString output;
 
 	//set the focus to the cscope tab
-	Notebook *book = m_mgr->GetOutputPaneNotebook();
+	wxBookCtrlBase *book = m_mgr->GetOutputPaneNotebook();
 
 	//make sure that the Output pane is visible
 	wxAuiManager *aui = m_mgr->GetDockingManager();
@@ -525,11 +532,13 @@ void Cscope::OnCScopeThreadUpdateStatus(wxCommandEvent &e)
 
 void Cscope::OnCscopeUI(wxUpdateUIEvent &e)
 {
+	CHECK_CL_SHUTDOWN();
 	bool isEditor = m_mgr->GetActiveEditor() ? true : false;
 	e.Enable(m_mgr->IsWorkspaceOpen() && isEditor);
 }
 
 void Cscope::OnWorkspaceOpenUI(wxUpdateUIEvent& e)
 {
+	CHECK_CL_SHUTDOWN();
 	e.Enable(m_mgr->IsWorkspaceOpen());
 }
