@@ -2,6 +2,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+#include <wx/string.h>
+#include <wx/regex.h>
+#include <map>
 
 #ifdef __WXMSW__
 #    include <windows.h>
@@ -15,60 +18,6 @@
  * helper string methods
  */
 
-/**
- * @brief return the string before the first occurance of 'c'
- * @param s input string
- * @param c delimiter char
- * @return string or the entire 's' string of 'c' is not found
- */
-std::string before_first(const std::string &s, char c)
-{
-	std::string::size_type where = s.find(c);
-	if (where == std::string::npos) {
-		return s;
-	}
-	return s.substr(0, where);
-}
-
-/**
- * @brief return string after the first occurance of 'c'
- * @param s input string
- * @param c delimiter char
- * @return string or empty string if 'c' is not found
- */
-std::string after_first(const std::string &s, char c)
-{
-	std::string::size_type where = s.find(c);
-	if (where == std::string::npos) {
-		return "";
-	}
-	return s.substr(where);
-}
-
-/**
- * @brief return true if s starts with prefix, false otherwise
- */
-bool starts_with(const std::string &s, const std::string &prefix)
-{
-	if (s.find(prefix) == 0) {
-		return true;
-	}
-	return false;
-}
-
-/**
- * @brief return true if s starts with prefix, false otherwise
- */
-bool ends_with(const std::string &s, const std::string &suffix, std::string &rest)
-{
-	std::string::size_type where = s.rfind(suffix);
-	if (where != std::string::npos && ((s.length() - where) == suffix.length()) ) {
-		rest = s.substr(where);
-		return true;
-	}
-	return false;
-}
-
 /**
  * @brief remove whitespaces from string
  * @param str
@@ -118,30 +67,6 @@ std::vector<std::string> string_tokenize(const std::string &str, const std::stri
 	return tokens;
 }
 
-/**
- * @brief Gets all characters before the last occurrence of c. Returns the empty string if c is not found
- */
-std::string before_last(const std::string &str, char c)
-{
-	std::string::size_type where = str.rfind(c);
-	if (where == std::string::npos) {
-		return "";
-	}
-	return str.substr(0, where);
-}
-
-/**
- * @brief Gets all the characters after the last occurrence of c. Returns the whole string if c is not found.
- */
-std::string after_last(const std::string &str, char c)
-{
-	std::string::size_type where = str.rfind(c);
-	if (where == std::string::npos) {
-		return str;
-	}
-	return str.substr(where+1);
-}
-
 // ------------------------------------------
 // Process manipulation
 // ------------------------------------------
@@ -169,3 +94,39 @@ bool is_process_alive(long pid)
 	return kill(pid, 0) == 0; // send signal 0 to process
 #endif
 }
+
+static std::map<wxString, wxRegEx*> s_regexPool;
+
+extern "C" char* regReplace(const char* src, const char* key, const char* value)
+{
+	wxString findWhat    = wxString(key,   wxConvUTF8);
+	wxString replaceWith = wxString(value, wxConvUTF8);
+	wxString inputStr    = wxString(src,   wxConvUTF8);
+	
+	
+	wxRegEx *re (NULL);
+	if(s_regexPool.find(findWhat) != s_regexPool.end()) {
+		re = s_regexPool.find(findWhat)->second;
+	}
+	
+	if(re == NULL) {
+		re = new wxRegEx(findWhat);
+	}
+	
+	if(!re->IsValid()) {
+		// invalid regular expression
+		// return a copy of the input string
+		delete re;
+		return strdup(src);
+	}
+	
+	// keep this instance
+	s_regexPool[findWhat] = re;
+	
+	// regex is valid, try to match
+	if(re->Matches(inputStr)) {
+		re->ReplaceAll(&inputStr, replaceWith);
+	}
+	
+	return strdup( inputStr.mb_str(wxConvUTF8).data() );
+}
