@@ -59,7 +59,7 @@ public:
 	//--------------------------------------------
 	//Abstract methods
 	//--------------------------------------------
-	virtual wxToolBar *CreateToolBar(wxWindow *parent);
+	virtual clToolBar *CreateToolBar(wxWindow *parent);
 	virtual void CreatePluginMenu(wxMenu *pluginsMenu);
 	virtual void HookPopupMenu(wxMenu *menu, MenuType type);
 	virtual void UnHookPopupMenu(wxMenu *menu, MenuType type);
